#
# spec file for package vagrant
#
# Copyright (c) 2021 SUSE LLC
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2012 Laurent Bigonville <bigon@debian.org>, License GPL-2.0+
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

# disable tests if you want to just run a quick build
%{bcond_without tests}

%global mod_name vagrant
%global mod_full_name %{mod_name}-%{version}
%global vim_data_dir %{_datadir}/vim/site/plugin/


Name:           vagrant
Version:        2.2.18
Release:        bp153.2.1
Summary:        Tool for building and distributing virtualized development environments
License:        MIT
Group:          Development/Languages/Ruby
URL:            https://github.com/hashicorp/vagrant
Source0:        %{URL}/archive/v%{version}/%{name}-%{version}.tar.gz
Source11:       vagrant.1
Source93:       vagrant_transfiletriggerin.rb
Source94:       vagrant_transfiletriggerun.rb
Source95:       vagrant_post.rb
Source96:       binstub
Source97:       macros.vagrant
Source98:       README.SUSE
Provides:       rubygem-vagrant = %{version}
Obsoletes:      rubygem-vagrant < %{version}
Recommends:     vagrant-libvirt
#
# Patches are maintained in the opensuse_package branch in the
# https://github.com/dcermak/vagrant.git repository.
# On every new release of vagrant, rebase them on top of the latest tag.
#
Patch1:         0001-bin-vagrant-silence-warning-about-installer.patch
Patch2:         0002-Use-a-private-temporary-dir.patch
Patch3:         0003-plugins-don-t-abuse-require_relative.patch.patch
Patch4:         0004-fix-vbox-package-boo-1044087-added-by-robert.muntean.patch
Patch5:         0005-do-not-depend-on-wdm.patch
Patch6:         0006-do-not-abuse-relative-paths-in-docker-plugin-to-make.patch
Patch7:         0007-Don-t-abuse-relative-paths-in-plugins.patch
Patch8:         0008-Skip-failing-tests.patch
Patch9:         0009-Disable-Subprocess-unit-test.patch
Patch10:        0010-Bump-listen-version-to-3.6.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

# force only one ruby version
# CAUTION: if you change this, then you *must* also change the sed calls which
#          fix these values in macros.vagrant
%if 0%{?suse_version} > 1500
%global rb_build_versions ruby30
%global rb_build_abi ruby:3.0.0
%global rb_ruby_suffix ruby3.0
%else
%global rb_build_versions %rb_default_ruby
%global rb_build_abi %rb_default_ruby_abi
%global rb_ruby_suffix %rb_default_ruby_suffix
%endif

# we use the rpm macros in this spec
# need to load them *after* defining the rb_* macros
%{?load:%{SOURCE97}}

%global vagrant_plugin_name vagrant


#===============================================================================
# Build dependencies
#===============================================================================

#  s.required_ruby_version     = ">= 2.5", "< 3.1"
%if 0%{?suse_version} > 1500
BuildRequires:  %{ruby:3 < 3.1}
%else
BuildRequires:  %{ruby:2 >= 2.5}
%endif
#
#
#
BuildRequires:  %{rubygem bundler}
#  s.add_dependency "bcrypt_pbkdf", "~> 1.1"
BuildRequires:  %{rubygem bcrypt_pbkdf:1 >= 1.1 }
#  s.add_dependency "childprocess", "~> 4.1.0"
BuildRequires:  %{rubygem childprocess:4.1 }
#  s.add_dependency "ed25519", "~> 1.2.4"
BuildRequires:  %{rubygem ed25519:1.2 >= 1.2.4 }
#  s.add_dependency "erubi"
BuildRequires:  %{rubygem erubi }
#  s.add_dependency "i18n", "~> 1.8"
BuildRequires:  %{rubygem i18n:1 >= 1.8 }
# PATCHED
#  s.add_dependency "listen", "~> 3.6"
BuildRequires:  %{rubygem listen:3 >= 3.6 }
#  s.add_dependency "hashicorp-checkpoint", "~> 0.1.5"
BuildRequires:  %{rubygem hashicorp-checkpoint:0.1 >= 0.1.5 }
#  s.add_dependency "log4r", "~> 1.1.9", "< 1.1.11"
BuildRequires:  %{rubygem log4r:1.1 >= 1.1.9 }
BuildConflicts:  %{rubygem log4r:1.1 >= 1.1.11 }
#  s.add_dependency "mime-types", "~> 3.3"
BuildRequires:  %{rubygem mime-types:3 >= 3.3 }
#  s.add_dependency "net-ssh", ">= 6.1.0", "< 6.2"
BuildRequires:  %{rubygem net-ssh:6.1 >= 6.1.0 }
#  s.add_dependency "net-sftp", "~> 3.0"
BuildRequires:  %{rubygem net-sftp:3 }
#  s.add_dependency "net-scp", "~> 3.0.0"
BuildRequires:  %{rubygem net-scp:3.0 }
#  s.add_dependency "rb-kqueue", "~> 0.2.0"
BuildRequires:  %{rubygem rb-kqueue:0.2 }
#  s.add_dependency "rexml", "~> 3.2"
BuildRequires:  %{rubygem rexml:3 >= 3.2 }
#  s.add_dependency "rubyzip", "~> 2.0"
BuildRequires:  %{rubygem rubyzip:2}
# Intentionally removed, wdm only works on Windows
# BuildRequires:  %%{rubygem wdm }
#  s.add_dependency "winrm", ">= 2.3.4", "< 3.0"
BuildRequires:  %{rubygem winrm:2 >= 2.3.4 }
#  s.add_dependency "winrm-fs", ">= 1.3.4", "< 2.0"
BuildRequires:  %{rubygem winrm-fs:1 >= 1.3.4 }
#  s.add_dependency "winrm-elevated", ">= 1.2.1", "< 2.0"
BuildRequires:  %{rubygem winrm-elevated:1 >= 1.2.1 }
#  s.add_dependency "vagrant_cloud", "~> 3.0.5"
BuildRequires:  %{rubygem vagrant_cloud:3.0 >= 3.0.5 }

# devel dependencies:
#  s.add_development_dependency "rake", "~> 13.0"
BuildRequires:  %{rubygem rake:13 }
#  s.add_development_dependency "rspec", "~> 3.10.0"
BuildRequires:  %{rubygem rspec:3.10 }
#  s.add_development_dependency "rspec-its", "~> 1.3.0"
BuildRequires:  %{rubygem rspec-its:1.3 }
#  s.add_development_dependency "fake_ftp", "~> 0.1.1"
BuildRequires:  %{rubygem fake_ftp:0.1 >= 0.1.1 }
#  s.add_development_dependency "webrick", "~> 1.7.0"
BuildRequires:  %{rubygem webrick:1.7 }

# Prevent have choice for rubygem(ruby:2.6.0:mime-types) >= 2
BuildRequires:  %{rubygem mime-types:3 }
# Prevent have choice for rubygem(ruby:2.6.0:builder) >= 2.1.2
BuildRequires:  %{rubygem builder:3.2 }
# Prevent have choice for rubygem(ruby:2.6.0:ffi:1) >= 1
BuildRequires:  %{rubygem ffi >= 1.9 }
# Prevent have choice for rubygem(ruby:2.5.0:thor:0) >= 0.18
BuildRequires:  %{rubygem thor:0.19}
# Prevent have choice for rubygem(ruby:2.5.0:addressable) >= 2.3.6
BuildRequires:  %{rubygem addressable >= 2.7}
# Prevent have choice for rubygem(ruby:2.5.0:public_suffix) >= 2.0.2
BuildRequires:  %{rubygem public_suffix:4}

# gem2rpm *must* be included as a direct dependency when building with a
# non-default ruby version
BuildRequires:  %{rubygem gem2rpm}
BuildRequires:  ruby-macros >= 5

# for the test
%if %{with tests}
BuildRequires:  openssh
BuildRequires:  curl
BuildRequires:  bsdtar
BuildRequires:  %{rubygem vagrant-spec}
%endif

BuildRequires:  fdupes

#===============================================================================
# Runtime dependencies
#===============================================================================

#  s.add_dependency "bcrypt_pbkdf", "~> 1.1"
Requires:       %{rubygem bcrypt_pbkdf:1 >= 1.1 }
#    s.add_dependency "childprocess", "~> 4.1.0"
Requires:       %{rubygem childprocess:4.1}
#   s.add_dependency "ed25519", "~> 1.2.4"
Requires:       %{rubygem ed25519:1.2 >= 1.2.4}
#  s.add_dependency "erubi"
Requires:       %{rubygem erubi}
#  s.add_dependency "i18n", "~> 1.8"
Requires:       %{rubygem i18n:1 >= 1.8}
# PATCHED
#  s.add_dependency "listen", "~> 3.6"
Requires:       %{rubygem listen:3 >= 3.6}
#  s.add_dependency "hashicorp-checkpoint", "~> 0.1.5"
Requires:       %{rubygem hashicorp-checkpoint:0.1 >= 0.1.5}
#  s.add_dependency "log4r", "~> 1.1.9", "< 1.1.11"
Requires:       %{rubygem log4r:1.1 >= 1.1.9 }
Requires:       %{rubygem log4r:1.1 < 1.1.11 }
#  s.add_dependency "mime-types", "~> 3.3"
Requires:       %{rubygem mime-types:3 >= 3.3}
#  s.add_dependency "net-ssh", ">= 6.1.0", "< 6.2"
Requires:       %{rubygem net-ssh:6.1 >= 6.1.0 }
#  s.add_dependency "net-sftp", "~> 3.0"
Requires:       %{rubygem net-sftp:3 }
#  s.add_dependency "net-scp", "~> 3.0.0"
Requires:       %{rubygem net-scp:3.0 }
#  s.add_dependency "rb-kqueue", "~> 0.2.0"
Requires:       %{rubygem rb-kqueue:0.2}
#  s.add_dependency "rexml", "~> 3.2"
Requires:       %{rubygem rexml:3 >= 3.2 }
#  s.add_dependency "rubyzip", "~> 2.0"
Requires:       %{rubygem rubyzip:2}
#   s.add_dependency "wdm", "~> 0.1.0"
# skip wdm, Windows only
#  s.add_dependency "winrm", ">= 2.3.4", "< 3.0"
Requires:       %{rubygem winrm:2 >= 2.3.4}
#  s.add_dependency "winrm-fs", ">= 1.3.4", "< 2.0"
Requires:       %{rubygem winrm-fs:1 >= 1.3.4}
#  s.add_dependency "winrm-elevated", ">= 1.2.1", "< 2.0"
Requires:       %{rubygem winrm-elevated:1 >= 1.2.1}
#  s.add_dependency "vagrant_cloud", "~> 3.0.5"
Requires:       %{rubygem vagrant_cloud:3.0 >= 3.0.5}


Requires:       bsdtar
Requires:       curl
Requires:       openssh

%description
Vagrant is a tool for building and distributing virtualized development
environments.

%package        doc
Summary:        Documentation for Vagrant
Group:          Documentation/HTML
BuildArch:      noarch

%description    doc
This package contains the documentation for vagrant.

%package        vim
Summary:        Vagrantfile syntax files for the vim editor
Group:          Development/Languages/Ruby
Supplements:    packageand(vagrant:vim)
BuildRequires:  vim
Requires:       vagrant = %{version}
Requires:       vim
BuildArch:      noarch

%description    vim
Optional dependency offering vim syntax files for Vagrantfile

%package        emacs
Summary:        Vagrantfile syntax files for the emacs editor
Group:          Development/Languages/Ruby
Supplements:    packageand(vagrant:emacs_program)
BuildRequires:  emacs-nox
Requires:       emacs_program
Requires:       vagrant = %{version}
BuildArch:      noarch

%description    emacs
Optional dependency offering emacs syntax files for Vagrantfile

%package bash-completion
Summary:        Vagrant bash autocompletion
Group:          Development/Languages/Ruby
Supplements:    packageand(vagrant:bash)
BuildRequires:  bash
BuildRequires:  bash-completion
Requires:       bash
Requires:       bash-completion
Requires:       vagrant = %{version}
BuildArch:      noarch

%description  bash-completion
Optional dependency offering bash completion for vagrant

%prep
%autosetup -p1 -n %{mod_full_name}

cp %{SOURCE98} .

%build
mv %{mod_name}.gemspec %{mod_full_name}.gemspec
%gem_build
mv %{mod_full_name}.gem %{_sourcedir}

%install

# cannot use %%vagrant_plugin_install here, as we provide a different --bindir
CONFIGURE_ARGS="--with-cflags='%{optflags}' $CONFIGURE_ARGS"
%gem_binary install -V -f --local --no-user-install \
    --ignore-dependencies --no-document --backtrace \
    --document=rdoc,ri \
    --install-dir %{buildroot}%{vagrant_plugin_dir} \
    --bindir %{buildroot}%{vagrant_plugin_dir}/bin %{_sourcedir}/%{mod_full_name}.gem

# the actual vagrant binary generated from the binstub
install -D -m 755 %{SOURCE96} %{buildroot}%{_bindir}/vagrant
gem_path=$(ruby.%{rb_ruby_suffix} -e "print Gem.path.reject{|path| path.include? 'home'}.join(':')")
sed -i -e "s|@vagrant_embedded_dir@|%{vagrant_embedded_dir}|" \
       -e "s|@ruby_vagrant_gem_path@|$gem_path:%{vagrant_plugin_dir}|" \
       -e "s|@vagrant_rb_ruby_suffix@|%{vagrant_rb_ruby_suffix}|" \
    %{buildroot}%{_bindir}/%{name}

# install the rpm macros & expand the name, name-version and vagrant_rb_* macros
%global macros_vagrant %{_rpmconfigdir}/macros.d/macros.%{name}
install -D -m 0644 %{SOURCE97} %{buildroot}%{macros_vagrant}
sed -i -e "s|%%{name}|%{name}|" \
       -e "s|%{name}-%%{version}|%{name}-%{version}|" \
       -e "s|%%{rb_build_versions}|%{rb_build_versions}|" \
       -e "s|%%{rb_build_abi}|%{rb_build_abi}|" \
       -e "s|%%{rb_ruby_suffix}|%{rb_ruby_suffix}|" \
    %{buildroot}%{macros_vagrant}

# install post, transfiletrigerin & transfiletriggerun scriptlets
%global post_rb %{vagrant_embedded_dir}/bin/vagrant_post.rb
%global transfiletriggerin_rb %{vagrant_embedded_dir}/bin/vagrant_transfiletriggerin.rb
%global transfiletriggerun_rb %{vagrant_embedded_dir}/bin/vagrant_transfiletriggerun.rb
install -D -m 0755 %{SOURCE93} %{buildroot}%{transfiletriggerin_rb}
install -D -m 0755 %{SOURCE94} %{buildroot}%{transfiletriggerun_rb}
install -D -m 0755 %{SOURCE95} %{buildroot}%{post_rb}

# expand macros in scriptlets
for file in %{post_rb} %{transfiletriggerin_rb} %{transfiletriggerun_rb}; do
    sed -i "s|%%{vagrant_dir}|%{vagrant_dir}|" %{buildroot}$file
    sed -i "s|%%{vagrant_plugin_conf}|%{vagrant_plugin_conf}|" %{buildroot}$file
    sed -i "s|%%{name}|%{name}|" %{buildroot}$file
    sed -i "s|%%{version}|%{version}|" %{buildroot}$file
    sed -i "s|%%{rb_ruby_suffix}|%{rb_ruby_suffix}|" %{buildroot}$file
done

# man page
install -D -m 644 %{SOURCE11} %{buildroot}%{_mandir}/man1/vagrant.1

# Bash completion: install it without the .sh ending, otherwise completion is broken
# and remove the shebang line in it
install -D -m 0644 %{buildroot}%{vagrant_dir}/contrib/bash/completion.sh \
    %{buildroot}%{_datadir}/bash-completion/completions/%{mod_name}
sed -i '1d' %{buildroot}%{_datadir}/bash-completion/completions/%{mod_name}

# Vim & Emacs syntax highlighting
install -D -m 0644 %{buildroot}%{vagrant_dir}/contrib/vim/vagrantfile.vim \
    %{buildroot}%{vim_data_dir}/%{mod_name}.vim
install -D -m 0644 %{buildroot}%{vagrant_dir}/contrib/emacs/vagrant.el \
    %{buildroot}%{_datadir}/emacs/site-lisp/%{mod_name}.el

chmod -x %{buildroot}%{vagrant_dir}/templates/locales/en.yml

# directories for vagrant plugins
mkdir -p %{buildroot}%{dirname:%{vagrant_plugin_cache}}
mkdir -p %{buildroot}%{dirname:%{vagrant_plugin_spec}}
mkdir -p %{buildroot}%{dirname:%{vagrant_plugin_docdir}}


# fix shebang in %%{vagrant_dir}/bin/%%{name}
sed -i 's|^\#\!/usr/bin/env.*|\#\!/usr/bin/ruby\.%{rb_ruby_suffix}|' \
    %{buildroot}%{vagrant_dir}/bin/%{name}

# remove versioned name from %%{vagrant_plugin_dir}/bin/%%{name}
# (aka /usr/share/vagrant/gems/bin/vagrant)
mv %{buildroot}%{vagrant_plugin_dir}/bin/%{name}.%{rb_ruby_suffix} \
    %{buildroot}%{vagrant_plugin_dir}/bin/%{name}


# Garbage collection
rm -f %{buildroot}%{vagrant_dir}/test/vagrant-spec/boxes/.keep
rm -f %{buildroot}%{vagrant_dir}/bin/vagrant.orig
rm -f %{buildroot}%{_bindir}/vagrant.orig.%{rb_ruby_suffix}
rm -f %{buildroot}%{vagrant_plugin_dir}/bin/vagrant.orig.%{rb_ruby_suffix}
rm -f %{buildroot}%{vagrant_dir}/lib/vagrant/util.rb.orig

# remove build script from vagrant
rm -f %{buildroot}%{vagrant_dir}/.runner.sh

%fdupes %{buildroot}%{dirname:%vagrant_plugin_dir}

%check

%if %{with tests}
# remove the git reference to vagrant-spec
# -> don't have to cleanup, the Gemfile is excluded anyway
sed -i "s|gem 'vagrant-spec', git.*$|gem 'vagrant-spec'|" Gemfile

export GEM_PATH=%{buildroot}%{vagrant_plugin_dir}:$(ruby.%{rb_ruby_suffix} -e "print Gem.path.reject{|path| path.include? 'home'}.join(':')")
bundle exec rake test:unit
%endif
# with tests

%pre
getent group vagrant >/dev/null || groupadd -r vagrant

%post
%{post_rb}

%transfiletriggerin -- %{dirname:%{vagrant_plugin_spec}}/
%{transfiletriggerin_rb}

%transfiletriggerun -- %{dirname:%{vagrant_plugin_spec}}/
%{transfiletriggerun_rb}

%files
%doc %{vagrant_dir}/CHANGELOG.md
%doc %{vagrant_dir}/README.md
%doc %{vagrant_dir}/README.SUSE
%license %{vagrant_dir}/LICENSE

%{_bindir}/%{name}
%{_mandir}/man1/%{name}.*

%{macros_vagrant}

# scriptlets
%dir %{dirname: %{post_rb}}
%{post_rb}
%{transfiletriggerin_rb}
%{transfiletriggerun_rb}

%dir %{vagrant_embedded_dir}
%ghost %{vagrant_plugin_conf}

# plugin directories
%dir %{vagrant_plugin_dir}
%dir %{vagrant_plugin_dir}/gems
%dir %{vagrant_plugin_dir}/bin
%dir %{dirname:%{vagrant_plugin_cache}}
%dir %{dirname:%{vagrant_plugin_spec}}
%dir %{dirname:%{vagrant_plugin_docdir}}

# vagrant's own files & directories
%{vagrant_plugin_cache}
%{vagrant_plugin_spec}
%{vagrant_plugin_dir}/bin/%{name}

%dir %{vagrant_dir}
%dir %{vagrant_dir}/bin
%dir %{vagrant_dir}/keys
%dir %{vagrant_dir}/lib
%dir %{vagrant_dir}/plugins
%dir %{vagrant_dir}/templates
%{vagrant_dir}/version.txt
%{vagrant_dir}/%{mod_full_name}.gemspec
%{vagrant_dir}/bin/%{name}
%{vagrant_dir}/keys/*
%{vagrant_dir}/lib/*
%{vagrant_dir}/plugins/*
%{vagrant_dir}/templates/*

# these are scripts for Hashicorp
%exclude %{vagrant_dir}/scripts/*
# either packaged in -vim -emacs subpackages or not relevant
%exclude %{vagrant_dir}/contrib
# various dotfiles we don't care about (.travis.yml et.al.)
%exclude %{vagrant_dir}/.*
# Development files
%exclude %{vagrant_dir}/Vagrantfile
%exclude %{vagrant_dir}/Rakefile
%exclude %{vagrant_dir}/Gemfile
%exclude %{vagrant_dir}/RELEASE.md
%exclude %{vagrant_dir}/tasks/*
# ruby configuration for acceptance tests
%exclude %{vagrant_dir}/vagrant-spec.config.example.rb

%files doc
%dir %{vagrant_plugin_docdir}
%doc %{vagrant_plugin_docdir}/rdoc
%doc %{vagrant_plugin_docdir}/ri

%files vim
%{vim_data_dir}/%{mod_name}.vim

%files emacs
%{_datadir}/emacs/site-lisp/%{mod_name}.el

%files bash-completion
%{_datadir}/bash-completion/completions/%{mod_name}

%changelog
* Tue Aug  3 2021 Dan Čermák <dcermak@suse.com>
- Switch to Ruby 3.0 on Tumbleweed
- New upstream release 2.2.18
  Rebase patches:
  * 0001-bin-vagrant-silence-warning-about-installer.patch
  * 0002-Use-a-private-temporary-dir.patch
  * 0003-plugins-don-t-abuse-require_relative.patch.patch
  * 0004-fix-vbox-package-boo-1044087-added-by-robert.muntean.patch
  * 0005-do-not-depend-on-wdm.patch
  * 0006-do-not-abuse-relative-paths-in-docker-plugin-to-make.patch
  * 0007-Don-t-abuse-relative-paths-in-plugins.patch
  * 0008-Skip-failing-tests.patch
  * 0009-Disable-Subprocess-unit-test.patch
  Removed patch:
  * 0010-Bump-listen-version-to-3.5.patch
  * 0011-Mock-the-PowerShell.executable-method-in-more-tests.patch
  * 0012-Use-systemctl-poweroff-in-the-background-instead-of-.patch
  * 0013-Include-rexml-dependency.patch
  * 0014-Bump-constraints-on-childprocess-and-net-scp.patch
  * 0015-Remove-no-longer-required-gem-webmock.patch
  Added patch:
  * 0010-Bump-listen-version-to-3.6.patch
  [#]# 2.2.18 (July 27, 2021)
  BUG FIXES:
- core: Fix of plugin manager kwargs [GH-12452]
- providers/docker: Pass in docker command opts as a map [GH-12449]
- providers/hyperv: Fix network address detection [GH-12472]
  [#]# 2.2.17 (July 7, 2021)
  FEATURES:
- guest/rocky: Add guest support for Rocky Linux [GH-12440]
  IMPROVEMENTS:
- command/package: Add --info flag to package command [GH-12304]
- guest/debian: Retry network setup on debain [GH-12421]
- guest/suse: Use systemctl poweroff in the background instead of shutdown [GH-12439]
- guest/windows: Get powershell path in %%WINDIR%%/System32 [GH-12436]
- host/windows: Check Domain and Application Directory contexts for credentials when validating SMB creds [GH-12428]
- providers/hyper-v: Fix IP detection when multiple devices are attached [GH-12232]
- provisioner/ansible: Detects new versions of ansible-4.0.0+ [GH-12391]
- provisioner/ansible: Strip whitespace from ansible version [GH-12420]
- provisioner/salt: Always use upstream Salt bootstrap script on Windows [GH-12127]
- provisioner/salt: Use more conservative TLS settings to work on older .NET versions [GH-12413]
- provisioner/shell: Buffer output to display full lines [GH-12437]
- vagrant: Updates to support Ruby 3.0 [GH-12427]
  BUG FIXES:
- command/cloud: Fix authentication middleware to prevent breaking local paths [GH-12419]
- communicator/ssh: Fix net-ssh patches for RSA signatures [GH-12415]
- core: Add box directly with authed urls [GH-12278]
* Tue Jul  6 2021 Dan Čermák <dcermak@suse.com>
- Remove no longer required gem webmock
  Rebase patches:
  * 0001-bin-vagrant-silence-warning-about-installer.patch
  * 0002-Use-a-private-temporary-dir.patch
  * 0003-plugins-don-t-abuse-require_relative.patch.patch
  * 0004-fix-vbox-package-boo-1044087-added-by-robert.muntean.patch
  * 0005-do-not-depend-on-wdm.patch
  * 0006-do-not-abuse-relative-paths-in-docker-plugin-to-make.patch
  * 0007-Don-t-abuse-relative-paths-in-plugins.patch
  * 0008-Skip-failing-tests.patch
  * 0009-Disable-Subprocess-unit-test.patch
  * 0010-Bump-listen-version-to-3.5.patch
  * 0011-Mock-the-PowerShell.executable-method-in-more-tests.patch
  * 0012-Use-systemctl-poweroff-in-the-background-instead-of-.patch
  * 0013-Include-rexml-dependency.patch
  * 0014-Bump-constraints-on-childprocess-and-net-scp.patch
  Added patch:
  * 0015-Remove-no-longer-required-gem-webmock.patch
* Tue Jul  6 2021 Dan Čermák <dcermak@suse.com>
- Bump childprocess version
  Rebase patches:
  * 0001-bin-vagrant-silence-warning-about-installer.patch
  * 0002-Use-a-private-temporary-dir.patch
  * 0003-plugins-don-t-abuse-require_relative.patch.patch
  * 0004-fix-vbox-package-boo-1044087-added-by-robert.muntean.patch
  * 0005-do-not-depend-on-wdm.patch
  * 0006-do-not-abuse-relative-paths-in-docker-plugin-to-make.patch
  * 0007-Don-t-abuse-relative-paths-in-plugins.patch
  * 0008-Skip-failing-tests.patch
  * 0009-Disable-Subprocess-unit-test.patch
  * 0010-Bump-listen-version-to-3.5.patch
  * 0011-Mock-the-PowerShell.executable-method-in-more-tests.patch
  * 0012-Use-systemctl-poweroff-in-the-background-instead-of-.patch
  Added patches:
  * 0013-Include-rexml-dependency.patch
  * 0014-Bump-constraints-on-childprocess-and-net-scp.patch
* Thu Jul  1 2021 Dan Čermák <dcermak@suse.com>
- Add patch to fix occasional shutdown failures with virtualbox
  Rebase patches:
  * 0001-bin-vagrant-silence-warning-about-installer.patch
  * 0002-Use-a-private-temporary-dir.patch
  * 0003-plugins-don-t-abuse-require_relative.patch.patch
  * 0004-fix-vbox-package-boo-1044087-added-by-robert.muntean.patch
  * 0005-do-not-depend-on-wdm.patch
  * 0006-do-not-abuse-relative-paths-in-docker-plugin-to-make.patch
  * 0007-Don-t-abuse-relative-paths-in-plugins.patch
  * 0008-Skip-failing-tests.patch
  * 0009-Disable-Subprocess-unit-test.patch
  * 0010-Bump-listen-version-to-3.5.patch
  * 0011-Mock-the-PowerShell.executable-method-in-more-tests.patch
  Added patches:
  * 0012-Use-systemctl-poweroff-in-the-background-instead-of-.patch
* Fri Apr 30 2021 Dan Čermák <dcermak@suse.com>
- New upstream release 2.2.16
  Rebase patches:
  * 0001-bin-vagrant-silence-warning-about-installer.patch
  * 0002-Use-a-private-temporary-dir.patch
  * 0003-plugins-don-t-abuse-require_relative.patch.patch
  * 0004-fix-vbox-package-boo-1044087-added-by-robert.muntean.patch
  * 0005-do-not-depend-on-wdm.patch
  * 0006-do-not-abuse-relative-paths-in-docker-plugin-to-make.patch
  * 0007-Don-t-abuse-relative-paths-in-plugins.patch
  * 0008-Skip-failing-tests.patch
  * 0009-Disable-Subprocess-unit-test.patch
  * 0010-Bump-listen-version-to-3.5.patch
  Added patches:
  * 0011-Mock-the-PowerShell.executable-method-in-more-tests.patch
  [#]# 2.2.16 (April 29, 2021)
  IMPROVEMENTS:
- guest/linux: Detect in process shutdown in reboot capability [GH-12302]
- util/powershell: Support `pwsh` executable in new versions of powershell [GH-12335]
  BUG FIXES:
- core: Add box directly with authed urls [GH-12278]
- communicator/ssh: Properly handle authentication with RSA keys [GH-12298]
- guest/fedora: Import guest detection module [GH-12275]
- guest/linux: Fix SMB folder mount name capability call [GH-12281]
- provider/docker: Properly handle updated buildkit build output [GH-12300]
* Tue Apr 27 2021 Dan Čermák <dcermak@suse.com>
- Bump rubygem-listen version to 3.5
  Rebase patches:
  * 0001-bin-vagrant-silence-warning-about-installer.patch
  * 0002-Use-a-private-temporary-dir.patch
  * 0003-plugins-don-t-abuse-require_relative.patch.patch
  * 0004-fix-vbox-package-boo-1044087-added-by-robert.muntean.patch
  * 0005-do-not-depend-on-wdm.patch
  * 0006-do-not-abuse-relative-paths-in-docker-plugin-to-make.patch
  * 0007-Don-t-abuse-relative-paths-in-plugins.patch
  * 0008-Skip-failing-tests.patch
  * 0009-Disable-Subprocess-unit-test.patch
  Add patch:
  * 0010-Bump-listen-version-to-3.5.patch
* Thu Apr  1 2021 Dan Čermák <dcermak@suse.com>
- New upstream release 2.2.15
  Rebase patches:
  * 0001-bin-vagrant-silence-warning-about-installer.patch
  * 0002-Use-a-private-temporary-dir.patch
  * 0003-plugins-don-t-abuse-require_relative.patch.patch
  * 0004-fix-vbox-package-boo-1044087-added-by-robert.muntean.patch
  * 0005-do-not-depend-on-wdm.patch
  * 0006-do-not-abuse-relative-paths-in-docker-plugin-to-make.patch
  * 0007-Don-t-abuse-relative-paths-in-plugins.patch
  * 0008-Skip-failing-tests.patch
  * 0009-Disable-Subprocess-unit-test.patch
  Remove patches (merged upstream):
  * 0010-Update-rake-to-13.0.patch
  * 0011-Bump-listen-gem-version-and-remove-ruby_dep.patch
  * 0012-Bump-bcrypt_pbkdf-version.patch
  [#]# 2.2.15 (March 30, 2021)
  IMPROVEMENTS:
- command/cloud: Remove access token URL parameter by default [GH-12234]
- command/cloud: Add VAGRANT_SERVER_ACCESS_TOKEN_BY_URL to revert access token behavior [GH-12252]
- core: Bump vagrant_cloud dependency to 3.0.3 [GH-12200]
- core: Bump listen gem version and remove ruby_dep [GH-12148]
- core: Bump vagrant_cloud dependency to 3.0.4 [GH-12242]
- core/bundler: Update resolution handling when outside of installer and bundler [GH-12225]
- core/plugin: Provide friendlier error messages on install fail when possible [GH-12225]
- guest/openwrt: Add support for OpenWrt guests [GH-11791]
- guest/freebsd: FreeBSD updated ansible to py37-ansible [GH-12201]
- provider/virtualbox: Get default dhcp ip from a matching host ip [GH-12211]
- util/downloader: Prevent redirect notification for default store [GH-12235]
  BUG FIXES:
- command/cloud: Automatically disable direct uploads when file is too large [GH-12250]
- core: Make shell script for loop shell agnostic [GH-12205]
- core: Raise error if downloading box metadata fails [GH-12189]
- core: Apply download options to metadata requests [GH-12177]
- core: Don't try to find "" by prefix in the machine index [GH-12188]
- core: Don't count not created machines as declined when destroying [GH-12186]
- core: Bump bcrypt_pbkdf version [GH-12216]
- core: Remove all space from checksums [GH-12168]
- core/bundler: Do not include default gems as pinned constraints [GH-12253]
- core/synced_folders: Extract os friendly mount name for vbox shared folders [GH-12184]
- guest/alpine: Check if interface exists before shutting it down [GH-12181]
- guest/nixos: Fix network config for recent NixOS releases [GH-12152]
- guest/fedora: Detect fedora using os-releases id [GH-12230]
* Mon Mar  1 2021 Dan Čermák <dcermak@suse.com>
- Fix removed dependency on bcrypt_pbkdf
  Rebase patches:
  * 0001-bin-vagrant-silence-warning-about-installer.patch
  * 0002-Use-a-private-temporary-dir.patch
  * 0003-plugins-don-t-abuse-require_relative.patch.patch
  * 0004-fix-vbox-package-boo-1044087-added-by-robert.muntean.patch
  * 0005-do-not-depend-on-wdm.patch
  * 0006-do-not-abuse-relative-paths-in-docker-plugin-to-make.patch
  * 0007-Don-t-abuse-relative-paths-in-plugins.patch
  * 0008-Skip-failing-tests.patch
  * 0009-Disable-Subprocess-unit-test.patch
  * 0010-Update-rake-to-13.0.patch
  * 0011-Bump-listen-gem-version-and-remove-ruby_dep.patch (was
    0012-Bump-listen-gem-version-and-remove-ruby_dep.patch)
  Added patch:
  * 0012-Bump-bcrypt_pbkdf-version.patch
  Removed patch:
  * 0011-Remove-not-required-bcrypt_pbkdf-gem.patch
* Fri Jan 29 2021 Dan Čermák <dcermak@suse.com>
- Remove pointless ruby_dep dependency and bump listen version
  Add patch:
  * 0012-Bump-listen-gem-version-and-remove-ruby_dep.patch
  Rebase patches:
  * 0001-bin-vagrant-silence-warning-about-installer.patch
  * 0002-Use-a-private-temporary-dir.patch
  * 0003-plugins-don-t-abuse-require_relative.patch.patch
  * 0004-fix-vbox-package-boo-1044087-added-by-robert.muntean.patch
  * 0005-do-not-depend-on-wdm.patch
  * 0006-do-not-abuse-relative-paths-in-docker-plugin-to-make.patch
  * 0007-Don-t-abuse-relative-paths-in-plugins.patch
  * 0008-Skip-failing-tests.patch
  * 0009-Disable-Subprocess-unit-test.patch
  * 0010-Update-rake-to-13.0.patch
  * 0011-Remove-not-required-bcrypt_pbkdf-gem.patch
* Fri Jan 22 2021 Dan Čermák <dcermak@suse.com>
- Remove not required bcrypt_pbkdf gem
  Add patch:
  * 0011-Remove-not-required-bcrypt_pbkdf-gem.patch
  Rebase patches:
  * 0001-bin-vagrant-silence-warning-about-installer.patch
  * 0002-Use-a-private-temporary-dir.patch
  * 0003-plugins-don-t-abuse-require_relative.patch.patch
  * 0004-fix-vbox-package-boo-1044087-added-by-robert.muntean.patch
  * 0005-do-not-depend-on-wdm.patch
  * 0006-do-not-abuse-relative-paths-in-docker-plugin-to-make.patch
  * 0007-Don-t-abuse-relative-paths-in-plugins.patch
  * 0008-Skip-failing-tests.patch
  * 0009-Disable-Subprocess-unit-test.patch
  * 0010-Update-rake-to-13.0.patch
* Fri Dec 11 2020 Dan Čermák <dcermak@suse.com>
- Patch rake version to ~> 13.0
  Add patch:
  * 0010-Update-rake-to-13.0.patch
  Rebase patches:
  * 0001-bin-vagrant-silence-warning-about-installer.patch
  * 0002-Use-a-private-temporary-dir.patch
  * 0003-plugins-don-t-abuse-require_relative.patch.patch
  * 0004-fix-vbox-package-boo-1044087-added-by-robert.muntean.patch
  * 0005-do-not-depend-on-wdm.patch
  * 0006-do-not-abuse-relative-paths-in-docker-plugin-to-make.patch
  * 0007-Don-t-abuse-relative-paths-in-plugins.patch
  * 0008-Skip-failing-tests.patch
  * 0009-Disable-Subprocess-unit-test.patch
* Thu Dec  3 2020 Dan Čermák <dcermak@suse.com>
- New upstream release 2.2.14
  remove rsync build dependency
  remove patch (fixed upstream):
  * 0010-Add-check-for-etc-fstab.patch
  rebased patches:
  * 0001-bin-vagrant-silence-warning-about-installer.patch
  * 0002-Use-a-private-temporary-dir.patch
  * 0003-plugins-don-t-abuse-require_relative.patch.patch
  * 0004-fix-vbox-package-boo-1044087-added-by-robert.muntean.patch
  * 0005-do-not-depend-on-wdm.patch
  * 0006-do-not-abuse-relative-paths-in-docker-plugin-to-make.patch
  * 0007-Don-t-abuse-relative-paths-in-plugins.patch
  * 0008-Skip-failing-tests.patch
  * 0009-Disable-Subprocess-unit-test.patch
  [#]# 2.2.14 (November 20, 2020)
  IMPROVEMENTS:
- host/windows: Update filesystem type matching on WSL2 [GH-12056]
  BUG FIXES:
- core: Track raw actions as they are applied to prevent multiple insertions [GH-12037]
- core/bundler: Update solution file resolution to support prerelease matching [GH-12054]
- guest/darwin: Mount vmware synced folders for big sur guests [GH-12053]
  [#]# 2.2.13 (November 06, 2020)
  BUG FIXES:
- core/bundler: Adjust request sets properly with non-development prerelease [GH-12025]
  [#]# 2.2.12 (November 06, 2020)
  BUG FIXES:
- core/bundler: Automatically enable prerelease dependency resolution [GH-12023]
  NOTE: This is a fix release to resolve an immediate issue with Vagrant
    plugin functionality
  [#]# 2.2.11 (November 05, 2020)
  IMPROVEMENTS:
- command/cap: Add ability to specify target [GH-11965]
- command/cloud: Add --force flag to `version release` command [GH-11912]
- command/cloud: Updates to utilize the 3.0 version of vagrant_cloud [GH-11916]
- core: Switch from unmaintained gem erubis to erubi [GH-11893]
- core: Download Vagrant boxes using auth headers [GH-11835]
- core: Remove dependency on mime gem [GH-11857]
- core: Handle Errno::EALREADY exceptions on port check [GH-12008]
- core: Fix missing hook/trigger insertion into action stack [GH-12014]
- guest/linux: Make max reboot wait duration configurable [GH-12011]
- guest/windows: Make max reboot wait duration configurable [GH-12011]
- providers/virtualbox: Fix availability check of provider [GH-11936]
- tests: Add integration tests for Docker provider [GH-11907]
  BUG FIXES:
- core/synced_folders: Don't persist synced folders to fstab if guest is not reachable [GH-11900]
- core: Don't try to recover machine without a uuid [GH-11863]
- config/disks: Transform provider specific config to common form [GH-11939]
- config/vm: Override synced-folder `:nfs` option [GH-11988]
- contrib/zsh: Remove newline from beginning of completion script [GH-11963]
- guests/arch: Install smbclient when setting up arch smb [GH-11923]
- guest/linux: Check for /etc/fstab before trying to modify [GH-11897]
- guest/linux: Create an /etc/fstab if does not exist [GH-11909]
- guest/linux: Persist SMB mounts [GH-11846]
- guest/debian: Set hostname in /etc/hosts as first step to changing hostname [GH-11885]
- guest/rhel: Check for existence of network files before trying to update them [GH-11877]
- guest/suse: Don't use hostnamectl to set hostname if not available on system [GH-11996]
- tests: Remove rsync dependency from tests [GH-11889]
* Wed Sep  9 2020 Dan Čermák <dcermak@suse.com>
- Switch back to using transfiletriggerin/un
- Increase required version of the addressable gem
- Allow to skip tests during development via bcond_without
- Add fix for boxes that don't have a /etc/fstab
  Added patch:
  * 0010-Add-check-for-etc-fstab.patch
  rebased patches:
  * 0001-bin-vagrant-silence-warning-about-installer.patch
  * 0002-Use-a-private-temporary-dir.patch
  * 0003-plugins-don-t-abuse-require_relative.patch.patch
  * 0004-fix-vbox-package-boo-1044087-added-by-robert.muntean.patch
  * 0005-do-not-depend-on-wdm.patch
  * 0006-do-not-abuse-relative-paths-in-docker-plugin-to-make.patch
  * 0007-Don-t-abuse-relative-paths-in-plugins.patch
  * 0008-Skip-failing-tests.patch
  * 0009-Disable-Subprocess-unit-test.patch
* Wed Aug 26 2020 Dan Čermák <dcermak@suse.com>
- New upstream release 2.2.10
  * add rsync to BuildRequires
  * run fdupes after installation
  Remove patches (merged upstream):
  * 0010-Bump-version-of-net-ssh-to-6.0-and-net-sftp-to-3.0.patch
  * 0011-Fixes-11606-Mock-out-guest-capabilities-instead-of-r.patch
  Rebased patches:
  * 0001-bin-vagrant-silence-warning-about-installer.patch
  * 0002-Use-a-private-temporary-dir.patch
  * 0003-plugins-don-t-abuse-require_relative.patch.patch
  * 0004-fix-vbox-package-boo-1044087-added-by-robert.muntean.patch
  * 0005-do-not-depend-on-wdm.patch
  * 0006-do-not-abuse-relative-paths-in-docker-plugin-to-make.patch
  * 0007-Don-t-abuse-relative-paths-in-plugins.patch
  * 0008-Skip-failing-tests.patch
  * 0009-Disable-Subprocess-unit-test.patch
  FEATURES:
  - hyperv/disks: Add ability to manage virtual disks for guests [GH-11541]
  IMPROVEMENTS:
  - core: Allow provisioners to be run when a communicator is not available [GH-11579]
  - core: Add `autocomplete` command that allows for install of bash or zsh autocomplete scripts [GH-11523]
  - core: Update to childprocess gem to 4.0.0 [GH-11717]
  - core: Add action to wait for cloud-init to finish running [GH-11773]
  - core: Update to net-ssh to 6.0 and net-sftp to 3.0 [GH-11621]
  - core: Optimize port in use check for faster validation [GH-11810]
  - core: Support for Ruby 2.7 [GH-11814]
  - core: Add synced folder capabilities for mount options and default fstab modification behavior [GH-11797]
  - guest/arch: Use systemd-networkd to configure networking for guests [GH-11400]
  - guest/haiku: Rsync install for rsync synced folders [GH-11614]
  - guest/solaris11: Add guest capability shell_expand_guest_path [GH-11759]
  - host/darwin: Add ability to build ISO [GH-11694]
  - hosts/linux: Add ability to build ISO [GH-11750]
  - hosts/windows: Add ability to build ISO [GH-11750]
  - providers/hyperv: Add support for SecureBootTemplate setting on import [GH-11756]
  - providers/hyperv: Add support for EnhancedSessionTransportType [GH-11014]
  - virtualbox/disks: Add ability to manage virtual dvds for guests [GH-11613]
  BUG FIXES:
  - core: Ensure MapCommandOptions class is required [GH-11629]
  - core: Fix `:all` special value on triggers [GH-11688]
  - core: Ensure network addresses have a valid netmask [GH-11679]
  - core: Recover local machine metadata in global index [GH-11656]
  - core: Print CLI help message is ambiguous option provided [GH-11746]
  - core: Update how `/etc/hosts` gets updated for darwin, freebsd and openbsd [GH-11719]
  - core: Capture `[3J` escape sequence [GH-11807]
  - core: Treat empty box value as invalid [GH-11618]
  - core: Allow forwarding ports to unknown addresses [GH-11810]
  - core: Scrub credentials as whole words [GH-11837]
  - commands/destroy: Add gracefull option to switch beween gracefully or forcefully shutting down a vm [GH-11628]
  - communicator/ssh: Raise an error for a nil exit status [GH-11721]
  - communicator/winrm: Check for nil return from querying for forwarded ports [GH-11831]
  - config/vm: Add option `allow_hosts_modification` to allow/disable Vagrant editing the guests `/etc/hosts` file [GH-11565]
  - config/vm: Add config option `hostname` to `config.vm.network` [GH-11566]
  - config/vm: Don't ignore NFS synced folders on Windows hosts [GH-11631]
  - host: Use regular port check for loopback addresses [GH-11654]
  - host: Allow windows and linux hosts to detach from rdp process [GH-11732]
  - host/windows: Properly register SMB password validation capability [GH-11795]
  - guests: Allow setting of hostname according to `hostname` option for multiple guests [GH-11704]
  - guest/alpine: Allow setting of hostname according to `hostname` option [GH-11718]
  - guest/esxi: Be more permissive with permissions of ssh directory [GH-11587]
  - guest/linux: Add virtual box shared folders to guest fstab [GH-11570]
  - guest/suse: Allow setting of hostname according to `hostname` option [GH-11567]
  - providers/docker: Ensure new containers don't grab existing bound ports [GH-11602]
  - providers/hyperv: Fix check for secure boot [GH-11809]
  - providers/virtualbox: Fix inability to create disk with same name across multiple guests [GH-11767]
  - provisioners/docker: Allow to specify docker image version using the `run` option [GH-11806]
  - provisioners/file: Allow creating empty folders [GH-11805]
  - provisioners/shell: Ensure Windows shell provisioner gets the correct file extension [GH-11644]
  - util/powershell: Use correct powershell executable for privileged commands [GH-11787]
* Tue Aug 18 2020 Dan Čermák <dcermak@suse.com>
- Use %%%%filetriggerin/-un until boo#1041742 gets resolved
* Mon May 18 2020 Dan Čermák <dcermak@suse.com>
- Use the correct ruby in the vagrant binstub as well
* Mon May 11 2020 Dan Čermák <dcermak@suse.com>
- New upstream release 2.2.9
  BUG FIXES:
  - core/bundler: Properly handle plugin install with available specification
    [GH-11592]
  - provisioners/docker: Fix CentOS docker install and start service
    capabilities [GH-11581]
  - provisioners/podman: Seperate RHEL install from CentOS install [GH-11584]
  Rebase patches:
  * 0001-bin-vagrant-silence-warning-about-installer.patch
  * 0002-Use-a-private-temporary-dir.patch
  * 0003-plugins-don-t-abuse-require_relative.patch.patch
  * 0004-fix-vbox-package-boo-1044087-added-by-robert.muntean.patch
  * 0005-do-not-depend-on-wdm.patch
  * 0006-do-not-abuse-relative-paths-in-docker-plugin-to-make.patch
  * 0007-Don-t-abuse-relative-paths-in-plugins.patch
  * 0008-Skip-failing-tests.patch
  * 0009-Disable-Subprocess-unit-test.patch
  Add patch:
  * 0010-Bump-version-of-net-ssh-to-6.0-and-net-sftp-to-3.0.patch
  * 0011-Fixes-11606-Mock-out-guest-capabilities-instead-of-r.patch
  - Fix various issues when building vagrant with a non-default ruby version
    (e.g. gem implicitly defaulting to the default one)
  - update README.SUSE
* Thu May  7 2020 Dan Čermák <dcermak@suse.com>
- New upstream release 2.2.8
  FEATURES:
  - virtualbox/disks: Add ability to manage virtual disks for guests [GH-11349]
  IMPROVEMENTS:
  - bin/vagrant: Automatically include global options within commands [GH-11473]
  - bin/vagrant: Suppress Ruby warnings when not running pre-release version
    [GH-11446]
  - communicator/ssh: Add support for configuring SSH connect timeout [GH-11533]
  - core: Update childprocess gem [GH-11487]
  - core: Add cli option `--no-tty` [GH-11414]
  - core: Overhaul call stack modifications implementation for hooks and
    triggers [GH-11455]
  - core/bundler: Cache plugin solution sets to speed up startup times
    [GH-11363]
  - config/vm: Add`box_download_options` config to specify extra download
    options for a box [GH-11560]
  - guest/alpine: Add ansible provisioner guest support [GH-11411]
  - guest/linux: Update systemd? check to use sudo [GH-11398]
  - guest/linux: Use systemd if available to halt and reboot system [GH-11407]
  - guests/linux: Mount smb folders with `mfsymlinks` option by default [GH-11503]
  - guest/redhat: Add support for SMB [GH-11463]
  - guest/windows: Rescue all regular exceptions during reboot wait [GH-11428]
  - providers/docker: Support catching container name when using podman [GH-11356]
  - provisioners/docker: Support Centos8 [GH-11462]
  - provisioners/podman: Add Podman as a provisioner [GH-11472]
  - provisioners/salt: Allow specifying python_version [GH-11436]
  BUG FIXES:
  - communicators/winssh: Fix issues with Windows SSH communicator [GH-11430]
  - core/bundler: Activate vagrant specification when not active [GH-11445]
  - core/bundler: Properly resolve sets when Vagrant is in prerelease [GH-11571]
  - core/downloader: Always set `-q` flag as first option [GH-11366]
  - core/hooks: Update dynamic action hook implementation to prevent looping
    [GH-11427]
  - core/synced_folders: Validate type option if set [GH-11359]
  - guests/debian: Choose netplan renderer based on network configuration and
    installed tools [GH-11498]
  - host/darwin: Quote directories in /etc/exports [GH-11441]
  - host/linux: Ensure `/etc/exports` does not contain duplicate records [GH-10591]
  - host/windows: Check all interfaces for port conflict when host_ip: "0.0.0.0"
    [GH-11454]
  - providers/docker: Fix issue where Vagrant fails to remove image if it is in
    use [GH-11355]
  - providers/docker: Fix issue with getting correct docker image id from build
    output [GH-11461]
  - providers/hyperv: Prevent error when identity reference cannot be translated
    [GH-11425]
  - provider/hyperv: Use service id for manipulating vm integration services
    [GH-11499]
  - providers/virtualbox: Parse `list dhcpservers` output on VirtualBox 6.1
    [GH-11404]
  - providers/virtualbox: Raise an error if guest IP ends in .1 [GH-11500]
  - provisioners/shell: Ensure windows shell provisioners always get an
    extension [GH-11517]
  - util/io: Fix encoding conversion errors [GH-11571]
  Removed patches:
  * 0003-linux-cap-halt-don-t-wait-for-shutdown-h-now-to-fini.patch
    (dropped as it is an old fix from Debian and Vagrant will now use systemd to
    shutdown, making this one obsolete)
  * 0004-plugins-don-t-abuse-require_relative.patch.patch
    (rebased as 0003-plugins-don-t-abuse-require_relative.patch.patch)
  * 0005-fix-vbox-package-boo-1044087-added-by-robert.muntean.patch
    (rebased as 0004-fix-vbox-package-boo-1044087-added-by-robert.muntean.patch)
  * 0006-do-not-depend-on-wdm.patch
    (rebased as 0005-do-not-depend-on-wdm.patch)
  * 0007-do-not-abuse-relative-paths-in-docker-plugin-to-make.patch
    (rebased as 0006-do-not-abuse-relative-paths-in-docker-plugin-to-make.patch)
  * 0008-Don-t-abuse-relative-paths-in-plugins.patch
    (rebased as 0007-Don-t-abuse-relative-paths-in-plugins.patch)
  * 0009-Fix-unit-tests-for-GuestLinux-Cap-Halt.patch
    (dropped as it is a test fix for Patch3)
  * 0010-Skip-failing-tests.patch
    (rebased as 0008-Skip-failing-tests.patch)
  * 0011-Do-not-list-load-dependencies-if-vagrant-spec-is-not.patch
    (merged upstream)
  * 0012-Disable-Subprocess-unit-test.patch
    (rebased as 0009-Disable-Subprocess-unit-test.patch)
  * 0013-Update-some-outdated-gem-versions.patch
    (merged upstream)
  Added patches:
  * 0003-plugins-don-t-abuse-require_relative.patch.patch
  * 0004-fix-vbox-package-boo-1044087-added-by-robert.muntean.patch
  * 0005-do-not-depend-on-wdm.patch
  * 0006-do-not-abuse-relative-paths-in-docker-plugin-to-make.patch
  * 0007-Don-t-abuse-relative-paths-in-plugins.patch
  * 0008-Skip-failing-tests.patch
  * 0009-Disable-Subprocess-unit-test.patch
* Fri Feb 14 2020 Dan Čermák <dcermak@suse.com>
- Fix non-restrictive dependency on rubygem-listen
* Wed Feb  5 2020 Dan Čermák <dcermak@suse.com>
- Bump the version of i18n, rubyzip and net-ssh
  Rebased patches:
  * 0001-bin-vagrant-silence-warning-about-installer.patch
  * 0002-Use-a-private-temporary-dir.patch
  * 0003-linux-cap-halt-don-t-wait-for-shutdown-h-now-to-fini.patch
  * 0004-plugins-don-t-abuse-require_relative.patch.patch
  * 0005-fix-vbox-package-boo-1044087-added-by-robert.muntean.patch
  * 0006-do-not-depend-on-wdm.patch
  * 0007-do-not-abuse-relative-paths-in-docker-plugin-to-make.patch
  * 0008-Don-t-abuse-relative-paths-in-plugins.patch
  * 0009-Fix-unit-tests-for-GuestLinux-Cap-Halt.patch
  * 0010-Skip-failing-tests.patch
  * 0011-Do-not-list-load-dependencies-if-vagrant-spec-is-not.patch
  * 0012-Disable-Subprocess-unit-test.patch
  Added patch:
  * 0013-Update-some-outdated-gem-versions.patch
* Tue Jan 28 2020 Dan Čermák <dcermak@suse.com>
- New upstream release 2.2.7
  IMPROVEMENTS:
  - guest/opensuse: Check for basename hostname prior to setting hostname [GH-11170]
  - host/linux: Check for modinfo in /sbin if it's not on PATH [GH-11178]
  - core: Show guest name in hostname error message [GH-11175]
  - provisioners/shell: Linux guests now support `reboot` option [GH-11194]
  - darwin/nfs: Put each NFS export on its own line [GH-11216]
  - contrib/bash: Add more completion flags to up command [GH-11223]
  - provider/virtualbox: Add VirtualBox provider support for version 6.1.x [GH-11250]
  - box/outdated: Allow to force check for box updates and ignore cached check [GH-11231]
  - guest/alpine: Update apk cache when installing rsync [GH-11220]
  - provider/virtualbox: Improve error message when machine folder is inaccessible [GH-11239]
  - provisioner/ansible_local: Add pip install method for arch guests [GH-11265]
  - communicators/winssh: Use Windows shell for `vagrant ssh -c` [GH-11258]
  BUG FIXES:
  - command/snapshot/save: Fix regression that prevented snapshot of all guests in environment [GH-11152]
  - core: Update UI to properly retain newlines when adding prefix [GH-11126]
  - core: Check if box update is available locally [GH-11188]
  - core: Ensure Vagrant::Errors are loaded in file_checksum util [GH-11183]
  - cloud/publish: Improve argument handling for missing arguments to command [GH-11184]
  - core: Get latest version for current provider during outdated check [GH-11192]
  - linux/nfs: avoid adding extra newlines to /etc/exports [GH-11201]
  - guest/darwin: Fix VMware synced folders on APFS [GH-11267]
  - guest/redhat: Ensure `nfs-server` is restarted when installing nfs client [GH-11212]
  - core: Do not validate checksums if options are empty string [GH-11211]
  - provider/docker: Enhance docker build method to match against buildkit output [GH-11205]
  - provisioner/ansible_local: Don't prompt for input when installing Ansible on Ubuntu and Debian [GH-11191]
  - provisioner/ansible_local: Ensure all guest caps accept all passed in arguments [GH-11265]
  - host/windows: Fix regression that prevented port collisions from being detected [GH-11244]
  - core/provisioner: Set top level provisioner name if set in a provisioner config [GH-11295]
  Rebased patches:
  * 0001-bin-vagrant-silence-warning-about-installer.patch
  * 0002-Use-a-private-temporary-dir.patch
  * 0003-linux-cap-halt-don-t-wait-for-shutdown-h-now-to-fini.patch
  * 0004-plugins-don-t-abuse-require_relative.patch.patch
  * 0005-fix-vbox-package-boo-1044087-added-by-robert.muntean.patch
  * 0006-do-not-depend-on-wdm.patch
  * 0007-do-not-abuse-relative-paths-in-docker-plugin-to-make.patch
  * 0008-Don-t-abuse-relative-paths-in-plugins.patch
  * 0009-Fix-unit-tests-for-GuestLinux-Cap-Halt.patch
  * 0010-Skip-failing-tests.patch
  Dropped patches:
  * 0011-Bump-rspec-its-dependency.patch
    (upstreamed)
  * 0012-Do-not-list-load-dependencies-if-vagrant-spec-is-not.patch
    (rebased as 0011-Do-not-list-load-dependencies-if-vagrant-spec-is-not.patch)
  * 0013-Catch-NetworkNoInterfaces-error-in-docker-prepare_ne.patch
    (upstreamed)
  * 0014-Bump-rubyzip-version-to-fix-CVE-2019-16892.patch
    (upstreamed)
  * 0015-ARM-only-Disable-Subprocess-unit-test.patch
    (rebased as 0012-Disable-Subprocess-unit-test.patch)
  * 0016-Ensure-nfsd-call-is-mocked-up-in-BSD-NFS-test.patch
    (upstreamed)
  Added patches:
  * 0011-Do-not-list-load-dependencies-if-vagrant-spec-is-not.patch
  * 0012-Disable-Subprocess-unit-test.patch
* Thu Dec 19 2019 Dan Čermák <dcermak@suse.com>
- Add fix for failing unit test
  Added patch from upstream (https://github.com/hashicorp/vagrant/pull/11155):
  - 0016-Ensure-nfsd-call-is-mocked-up-in-BSD-NFS-test.patch
  Rebased patches:
  - 0001-bin-vagrant-silence-warning-about-installer.patch
  - 0002-Use-a-private-temporary-dir.patch
  - 0003-linux-cap-halt-don-t-wait-for-shutdown-h-now-to-fini.patch
  - 0004-plugins-don-t-abuse-require_relative.patch.patch
  - 0005-fix-vbox-package-boo-1044087-added-by-robert.muntean.patch
  - 0006-do-not-depend-on-wdm.patch
  - 0007-do-not-abuse-relative-paths-in-docker-plugin-to-make.patch
  - 0008-Don-t-abuse-relative-paths-in-plugins.patch
  - 0009-Fix-unit-tests-for-GuestLinux-Cap-Halt.patch
  - 0010-Skip-failing-tests.patch
  - 0011-Bump-rspec-its-dependency.patch
  - 0012-Do-not-list-load-dependencies-if-vagrant-spec-is-not.patch
  - 0013-Catch-NetworkNoInterfaces-error-in-docker-prepare_ne.patch
  - 0015-ARM-only-Disable-Subprocess-unit-test.patch
* Wed Nov 13 2019 Dan Čermák <dcermak@suse.com>
- Add rubyzip to as Requires: and bump its version to 1.3
  This is required to address CVE-2019-16892
  Rebased patches:
  - 0001-bin-vagrant-silence-warning-about-installer.patch
  - 0002-Use-a-private-temporary-dir.patch
  - 0003-linux-cap-halt-don-t-wait-for-shutdown-h-now-to-fini.patch
  - 0004-plugins-don-t-abuse-require_relative.patch.patch
  - 0005-fix-vbox-package-boo-1044087-added-by-robert.muntean.patch
  - 0006-do-not-depend-on-wdm.patch
  - 0007-do-not-abuse-relative-paths-in-docker-plugin-to-make.patch
  - 0008-Don-t-abuse-relative-paths-in-plugins.patch
  - 0009-Fix-unit-tests-for-GuestLinux-Cap-Halt.patch
  - 0010-Skip-failing-tests.patch
  - 0011-Bump-rspec-its-dependency.patch
  - 0012-Do-not-list-load-dependencies-if-vagrant-spec-is-not.patch
  - 0013-Catch-NetworkNoInterfaces-error-in-docker-prepare_ne.patch
  Removed:
  - 0014-ARM-only-Disable-Subprocess-unit-test.patch
  Added:
  - 0014-Bump-rubyzip-version-to-fix-CVE-2019-16892.patch
  - 0015-ARM-only-Disable-Subprocess-unit-test.patch
* Tue Oct 22 2019 Dan Čermák <dcermak@suse.com>
- Rebased patches:
  - 0001-bin-vagrant-silence-warning-about-installer.patch
  - 0002-Use-a-private-temporary-dir.patch
  - 0003-linux-cap-halt-don-t-wait-for-shutdown-h-now-to-fini.patch
  - 0004-plugins-don-t-abuse-require_relative.patch.patch
  - 0005-fix-vbox-package-boo-1044087-added-by-robert.muntean.patch
  - 0006-do-not-depend-on-wdm.patch
  - 0007-do-not-abuse-relative-paths-in-docker-plugin-to-make.patch
  - 0008-Don-t-abuse-relative-paths-in-plugins.patch
  - 0009-Fix-unit-tests-for-GuestLinux-Cap-Halt.patch
  - 0010-Skip-failing-tests.patch
  - 0011-Bump-rspec-its-dependency.patch
  - 0012-Do-not-list-load-dependencies-if-vagrant-spec-is-not.patch
  Dropped (integrated upstream or made obsolete by upstream fixes):
  - 0013-Only-return-interfaces-where-addr-is-not-nil.patch
  - 0014-Skip-docker-networking-test.patch
  Removed:
  - 0015-ARM-only-Disable-Subprocess-unit-test.patch
  Added:
  - 0013-Catch-NetworkNoInterfaces-error-in-docker-prepare_ne.patch
  - 0014-ARM-only-Disable-Subprocess-unit-test.patch
  This update fixes boo#1150592
* Fri Oct 18 2019 Johannes Kastl <kastl@b1-systems.de>
- update to 2.2.6
  - dropped patch 0013-Only-return-interfaces-where-addr-is-not-nil.patch that has been included upstream
  - set vagrant_cloud dependency to >= 2.0.3
  FEATURES:
    core/provisioners: Introduce new Provisioner options: before and after [GH-11043]
    guest/alpine: Integrate the vagrant-alpine plugin into Vagrant core [GH-10975]
  IMPROVEMENTS:
    command/box/prune: Allow prompt skip while preserving actively in use boxes [GH-10908]
    command/cloud: Support providing checksum information with boxes [GH-11101]
    dev: Fixed Vagrantfile for Vagrant development [GH-11012]
    guest/alt: Improve handling for using network tools when setting hostname [GH-11000]
    guest/suse: Add ipv6 network config templates for SUSE based distributions [GH-11013]
    guest/windows: Retry on connection timeout errors for the reboot capability [GH-11093]
    host/bsd: Use host resolve path capability to modify local paths if requird [GH-11108]
    host/darwin: Add host resolve path capability to provide real paths for firmlinks [GH-11108]
    provisioners/chef: Update pkg install flags for chef on FreeBSD guests [GH-11075]
    provider/hyperv: Improve error message when VMMS is not running [GH-10978]
    provider/virtualbox: Raise additional errors for incomplete virtualbox installation on usable check [GH-10938]
    util/filechecksum: Add support for more checksum types [GH-11101]
  BUG FIXES:
    command/rsync-auto: Fix path watcher bug so that all subdirectories are synced when changed [GH-11089]
    command/snapshot/save: Ensure VM id is passed to list snapshots for hyper-v provider [GH-11097]
    core: Ensure proper paths are shown in config loading exceptions [GH-11056]
    guest/suse: Use hostnamectl instead of hostname to set the hostname under SUSE [GH-11100]
    provider/docker: Fix default provider validation if password is used [GH-11053]
    provider/docker: Fix Docker providers usable? check [GH-11068]
    provisioner/ansible_local: Ensure pip_install_cmd is finalized to emptry string [GH-11098]
    provisioner/file: Ensure relative path for file provisioner source is relative to guest machines cwd [GH-11099]
    provider/docker: Ensure docker build_args option is properly set in docker compose config yaml [GH-11106]
    guest/suse: Update nfs & service daemon names for suse based hosts and guests [GH-11076]
    provider/docker: Determine ip address prefix workaround for docker public networks [GH-11111]
    provider/docker: Only return interfaces where addr is not nil for networks [GH-11116]
* Wed Aug 28 2019 Dan Čermák <dcermak@suse.com>
- Rebase vagrant patches:
  drop:
  - 0002-bin-vagrant-silence-warning-about-installer.patch
  - 0003-Use-a-private-temporary-dir.patch
  - 0004-linux-cap-halt-don-t-wait-for-shutdown-h-now-to-fini.patch
  - 0009-plugins-don-t-abuse-require_relative.patch
  - 0023-vbox-fix-package.patch
  - 0024-do-not-depend-on-wdm.patch
  - 0025-do-not-abuse-relative-paths-in-docker-plugin.patch
  - 0026-do-not-abuse-relative-paths-in-plugins.patch
  - 0027-Fix-unit-tests-for-GuestLinux-Cap-Halt.patch
  - 0028-Skip-failing-tests.patch
  - 0029-Skip-docker-networking-test.patch
  add:
  - 0001-bin-vagrant-silence-warning-about-installer.patch
  - 0002-Use-a-private-temporary-dir.patch
  - 0003-linux-cap-halt-don-t-wait-for-shutdown-h-now-to-fini.patch
  - 0004-plugins-don-t-abuse-require_relative.patch.patch
  - 0005-fix-vbox-package-boo-1044087-added-by-robert.muntean.patch
  - 0006-do-not-depend-on-wdm.patch
  - 0007-do-not-abuse-relative-paths-in-docker-plugin-to-make.patch
  - 0008-Don-t-abuse-relative-paths-in-plugins.patch
  - 0009-Fix-unit-tests-for-GuestLinux-Cap-Halt.patch
  - 0010-Skip-failing-tests.patch
  - 0011-Bump-rspec-its-dependency.patch
  - 0012-Do-not-list-load-dependencies-if-vagrant-spec-is-not.patch
  - 0013-Only-return-interfaces-where-addr-is-not-nil.patch
  - 0014-Skip-docker-networking-test.patch
  - 0015-ARM-only-Disable-Subprocess-unit-test.patch
* Mon Jul  1 2019 Dan Čermák <dcermak@suse.com>
- Add 0029-Skip-docker-networking-test.patch:
    skips a unit-test that fails on OBS
  update to 2.2.5
  FEATURES:
    providers/docker: Private and Public networking support [GH-10702]
  IMPROVEMENTS:
    command/global-status: Provide machine-readable information [GH-10506]
    command/snapshot: Separate snapshot names for guests when listing snapshots [GH-10828]
    command/box/update: Ignore missing metadata files when updating all boxes [GH-10829]
    core: Use consistent settings when unpacking boxes as root [GH-10707]
    core: Write metadata.json file when packaging box [GH-10706]
    core: Remove whitespace from id file on load [GH-10727]
    core/bundler: Support resolution when installed within system [GH-10894]
    guest/coreos: Update network configuration and hostname setting [GH-10752]
    guest/freebsd: Add proper VirtualBox share folders support for FreeBSD guests [GH-10717]
    guest/freebsd: Add unmount share folder for VirtualBox guests [GH-10761]
    guest/freebsd: Simplify network interface listing when configuring networks [GH-10763]
    providers/docker: Add usable? check to docker provider [GH-10890]
    synced_folder/smb: Remove configuration information from synced folder data [GH-10811]
  BUG FIXES:
    command/box/update: Ensure the right version is picked when updating specific boxes [GH-10810]
    command/cloud: Properly set variable from CLI argument parsing for username field [GH-10726]
    command/rsync_auto: Use relative paths to machines folder path for file path Listener [GH-10902]
    communicator/ssh: Remove net/sftp loading to prevent loading errors [GH-10745]
    contrib/bash: Search for running_vm_list only in machines folder [GH-10841]
    core/bundler: Properly parse multiple constants when installing plugins [GH-10896]
    core/environment: Support plugin configuration within box Vagrantfiles [GH-10889]
    core/triggers: Fix typo in UI output [GH-10748]
    core/triggers: Properly exit with abort option [GH-10824]
    core/triggers: Ensure guest names are string when filtering trigger configs [GH-10854]
    core/triggers: Abort after all running processes have completed when parallel is enabled [GH-10891]
    guest/void: Fix NFS capability detection [GH-10713]
    guest/bsd: Properly set BSD options order for /etc/exports [GH-10909]
    host/windows: Fix rubygems error when host has directory named c [GH-10803]
    provider/virtualbox: Ensure non-existent machines do not attempt to list snapshots [GH-10784]
    provider/docker: Properly set docker-compose config file with volume names [GH-10820]
    provisioner/ansible: Fix pip installer hardcoded curl get_pip.py piped to python [GH-10625]
    provisioner/chef: Update chef install check for guests [GH-10917]
    synced_folders/rsync: Remove rsync__excludes from command if array is empty [GH-10901]
* Tue Apr  2 2019 Dan Čermák <dcermak@suse.com>
- Restructure vagrant package to support system-wide plugin installation
  * Add 0027-Fix-unit-tests-for-GuestLinux-Cap-Halt.patch:
    fixes unit tests due to changes made by patch4
  * Add 0028-Skip-failing-tests.patch:
    skips two failing unit tests
* Wed Mar 20 2019 Robert Frohl <rfrohl@suse.com>
- update to 2.2.4
  FEATURES:
  - core/triggers: Introduce new option :type for actions, hooks, and commands [GH-10615]
  IMPROVEMENTS:
  - communicator/ssh: Update #upload behavior to work properly with new sshd path checks [GH-10698]
  - communicator/winrm: Update #upload behavior to match ssh communicator upload behavior [GH-10698]
  - guest/windows: Add reboot output to guest capability [GH-10638]
  - provisioner/file: Refactor path modification rules and allow communicator to handle details [GH-10698]
  BUG FIXES:
  - core: Fix format finalization of plugins in Vagrantfile [GH-10664]
  - core: Fix SIGINT behavior and prevent backtrace [GH-10666]
  - core: Change remaining box_client_cert refs to box_download_client_cert [GH-10622]
  - core: Move over AddAuthentication middleware and hooks out of deprecated class [GH-10686]
  - guest/debian: Properly set DHCP for systemd-networkd ips [GH-10586]
  - guest/solaris11: Create interface if required before configuration [GH-10595]
  - installers/appimage: Use ld path with appimage libs on suffix [GH-10647]
  - providers/docker: Expand paths when comparing synced folders on reload [GH-10645]
  - providers/virtualbox: Fix import paths on Windows with VirtualBox 6 [GH-10629]
  - synced_folders/rsync: Properly clean up tmp folder created during rsync [GH-10690]
- update to 2.2.3
  FEATURES:
  - host/void: Add host support for void linux [GH-10012]
  IMPROVEMENTS:
  - command/rsync-auto: Prevent crash on post-rsync command failure [GH-10515]
  - command/snapshot: Raise error for bad subcommand [GH-10470]
  - command/package: Ensure temp dir for package command is cleaned up [GH-10479]
  - command/powershell: Support running elevated commands [GH-10528]
  - communicator/ssh: Add config and remote_user options [GH-10496]
  - core: Display version update on stderr instead of stdout [GH-10482]
  - core: Add experimental feature flag [GH-10485]
  - core: Show box version during box outdated check [GH-10573]
  - guest/windows: Modify elevated username only on username failure [GH-10488]
  - host/windows: Prevent SMB setup commands from becoming too long [GH-10489]
  - host/windows: Automatically answer yes when pruning SMB shares [GH-10524]
  - provisioners/file: Show source and destination locations with file provisioner [GH-10570]
  - provisioners/salt: Validate that install_type is set if version is specified [GH-10474]
  - provisioners/salt: Update default install version [GH-10537]
  - provisioners/shell: Add reboot option for rebooting supported guest [GH-10532]
  - synced_folders/rsync: Support using rsync --chown option [GH-10529]
  - util/guest_inspection: Validate hostnamectl command works when detected [GH-10512]
  - util/platform: Use wslpath command for customized root on WSL [GH-10574]
  BUG FIXES:
  - command/cloud publish: Ensure box file exists before path expanding [GH-10468]
  - command/cloud publish: Catch InvalidVersion errors from vagrant_cloud client [GH-10513]
  - command/snapshot: Retain consistent provisioning behavior across all commands [GH-10490]
  - command/validate: Bypass install checks for validating configs with the --ignore-provider flag [GH-10467]
  - communicator/ssh: Fix garbage output detection [GH-10571]
  - guest/alt: Fix network configuration errors [GH-10527]
  - guest/coreos: Fix grep command for network interface of CoreOS guest [GH-10554]
  - guest/freebsd: Fix defaultrouter rcvar in static network template [GH-10469]
  - guest/redhat: Fix network configuration errors [GH-10527]
  - providers/virtualbox: Adjust version requirement for NIC warning [GH-10486]
  - util/powershell: Use correct Base64 encoding for encoded commands [GH-10487]
- Rebased 0002-bin-vagrant-silence-warning-about-installer.patch as context changed
* Mon Mar  4 2019 Ana María Martínez Gómez <ammartinez@suse.com>
- Correct the gem versions
* Mon Jan 28 2019 Dan Čermák <dcermak@suse.com>
- Update Requires and Buildrequires to match vagrant.gemspec
* Fri Jan 11 2019 Dan Čermák <dcermak@suse.com>
- Add 0026-do-not-abuse-relative-paths-in-plugins.patch:
  this further removes usage of relative paths in vagrant
* Fri Jan  4 2019 Dan Čermák <dcermak@suse.com>
- update to 2.2.2
  BUG FIXES:
  - providers/virtualbox: Update default_nic_type implementation and add warning [GH-10450]
- update to 2.2.1
  FEATURES:
  - core/plugins: Add reset! method to communicator [GH-10399]
  - providers/virtualbox: Add support for VirtualBox 6.0 [GH-10379]
  IMPROVEMENTS:
  - command/validate: Allow validation of config while ignoring provider [GH-10351]
  - communicators/ssh: Prevent overly verbose output waiting for connection [GH-10321]
  - communicators/ssh: Support ed25519 keys [GH-10365]
  - communicators/ssh: Add reset! implementation [GH-10399]
  - communicators/winrm: Add reset! implementation [GH-10399]
  - core: Limit number of automatic box update checks [GH-10359]
  - host/windows: Remove PATH check in WSL detection [GH-10313]
  - providers/hyperv: Disable automatic checkpoints before deletion [GH-10406]
  - providers/virtualbox: Add `automount` flag if specified with synced_folder [GH-10326]
  - providers/virtualbox: Refactor host only network settings [GH-7699]
  - providers/virtualbox: Support setting default NIC type for network adapters [GH-10383]
  - providers/virtualbox: Update ssh_port helper to handle multiple matches [GH-10409]
  - provisioners/shell: Add :reset option to allow communicator reset [GH-10399]
  - synced_folders/smb: Allow for 'default' smb_username in prompt if set [GH-10319]
  - util/network_ip: Simplify `network_address` helper [GH-7693]
  - util/platform: Prevent hard failure during hyper-v enabled check [GH-10332]
  BUG FIXES:
  - command/login: Only show deprecation warning when command is invoked [GH-10374]
  - core: Fallback to Vagrantfile defined box information [GH-10368]
  - core/bundler: Update source ordering to properly resolve with new RubyGems [GH-10364]
  - core/triggers: Only split inline script if host is non-Windows [GH-10405]
  - communicator/winrm: Prepend computer name to username when running elevated commands [GH-10387]
  - guest/debian: Fix halting issue when setting hostname by restarting networking on guest [GH-10301, GH-10330]
  - guest/linux: Fix vagrant user access to docker after install [GH-10399]
  - guest/windows: Add reboot capability to fix hostname race condition [GH-10347]
  - guest/windows: Allow for reading key paths with spaces [GH-10389]
  - host/windows: Fix powershell to properly handle paths with spaces [GH-10390]
  - providers/docker: Deterministic host VM synced folder location for Docker VM [GH-10311]
  - providers/hyperv: Fix network vlan configuration script [GH-10366]
  - providers/hyperv: Properly output error message on failed guest import [GH-10404]
  - providers/hyperv: Fix typo in network configuration detection script [GH-10410]
* Fri Nov 16 2018 Johannes Kastl <kastl@b1-systems.de>
- update to 2.2.0
  FEATURES:
  - command/cloud: Introduce `vagrant cloud` subcommand to Vagrant [GH-10148]
  - command/upload: Add command for uploading files to guest [GH-10263]
  - command/winrm: Add command for executing guest commands via WinRM [GH-10263]
  - command/winrm-config: Add command for providing WinRM configuration [GH-10263]
  IMPROVEMENTS:
  - core: Ensure file paths are identical when checking for cwd [GH-10220]
  - core: Add config option `ignore_box_vagrantfile` for ignoring vagrantfile inside box [GH-10242]
  - core/triggers: Add abort option to core triggers [GH-10232]
  - core/triggers: Introduce `ruby` option for trigger [GH-10267]
  - contrib/bash: Add completion for snapshot names for vagrant snapshot restore|delete [GH-9054]
  - providers/docker: Build docker from git repo [GH-10221]
  - providers/hyperv: Update Hyper-V admin check and allow override via ENV variable [GH-10275]
  - providers/virtualbox: Allow base_mac to be optional [GH-10255]
  - provisioners/salt: bootstrap-salt.sh: use -s with curl [GH-9432]
  - provisioners/salt: remove leading space with bootstrap_options [GH-9431]
  BUG FIXES:
  - core/environment: Provide rgloader for local plugin installations [GH-10279]
  - contrib/sudoers/osx: Fix missing comma and add remove export alias [GH-10235]
  - guest/redhat: Update restart logic in redhat change_host_name cap [GH-10223]
  - guest/windows: Allow special characters in SMB password field [GH-10219]
  - providers/hyperv: Only use AutomaticCheckpointsEnabled when available [GH-10264]
  - providers/hyperv: Only use CheckpointType when available [GH-10265]
  - provisioners/ansible: Fix remote directory creation [GH-10259, GH-10258]
  - provisioners/puppet: Properly set env variables for puppet provisioner on windows [GH-10218]
  - provisioners/salt: Properly set salt pillar variables for windows guests [GH-10215]
  - synced_folders/rsync: Ensure unique tmp dirs for ControlPath with rsync [GH-10291]
* Fri Nov 16 2018 Johannes Kastl <kastl@b1-systems.de>
- update to 2.1.5
  IMPROVEMENTS:
  - core: Add `Vagrant.version?` helper method [GH-10191]
  - core: Scrub sensitive values from logger output [GH-10200]
  - core: Prevent multiple evaluations of Vagrantfile [GH-10199]
  - command/init: Support VAGRANT_DEFAULT_TEMPLATE env var [GH-10171]
  - command/powershell: Improve doc help string and fix winrm locales error [GH-10189]
  - contrib/bash: autocomplete running VM names for destroy subcommand [GH-10168]
  - guest/debian: Use `sudo` to determine if systemd is in use for hardened systems [GH-10198]
  - guest/openbsd: Add IPv6 network template for OpenBSD machines [GH-8912]
  - provisioners/salt: Allow non-windows hosts to pass along version [GH-10194]
  BUG FIXES:
  - core: Fix Vagrant.has_plugin? behavior before plugins are initialized [GH-10165]
  - core: Check verify_host_key for falsey or :never values when generating ssh config [GH-10182]
  - guest/linux: Filter out empty strings and loopback interfaces when constructing list of network interfaces [GH-10092]
  - provider/hyper-v: Check for automatic checkpoint support before configuring [GH-10181]
* Fri Nov 16 2018 Johannes Kastl <kastl@b1-systems.de>
- update to 2.1.4
  BUG FIXES:
  - core: Fix local plugin installation prompt answer parsing [GH-10154]
  - core: Reset internal environment after plugin loading [GH-10155]
  - host/windows: Fix SMB list parsing when extra fields are included [GH-10156]
* Fri Nov 16 2018 Johannes Kastl <kastl@b1-systems.de>
- update to 2.1.3
  FEATURES:
  - core: Support for project specific plugins [GH-10037]
  IMPROVEMENTS:
  - command\/reload: Add `--force` flag to reload command [GH-10123]
  - communicator/winrm: Display warning if vagrant-winrm plugin is detected [GH-10076]
  - contrib/bash: Replace -VAGRANTSLASH  - with literal slash in completion [GH-9987]
  - core: Show installed version of Vagrant when displaying version check [GH-9968]
  - core: Retain information of original box backing active guest [GH-10083]
  - core: Only write box info if provider supports box objects [GH-10126]
  - core: Update net-ssh dependency constraint to ~> 5.0.0 [GH-10066]
  - core/triggers: Catch and allow for non-standard exit codes with triggers `run` options [GH-10005]
  - core/triggers: Allow for spaces in `path` for trigger run option [GH-10118]
  - guest/debian: Isolate network interface configuration to individual files for systemd [GH-9889]
  - guest/redhat: Use libnfs-utils package if available [GH-9878]
  - provider/docker: Support Docker volume consistency for synced folders [GH-9811]
  - provider/hyperv: Disable synced folders on non-DrvFs file systems by default [GH-10001]
  - util/downloader: Support custom suffix on user agent string [GH-9966]
  - util/downloader: Prevent false positive matches on Location header [GH-10041]
  - util/subprocess: Force system library paths for executables external to AppImage [GH-10078]
  BUG FIXES:
  - core: Disable Vagrantfile loading with plugin commands [GH-10030]
  - core: Ensure the SecureRandom library is loaded for the trigger class [GH-10063]
  - core/triggers: Allow trigger run args option to be a single string [GH-10116]
  - util/powershell: Properly `join` commands from passed in array [GH-10115]
  - guest/solaris: Add back guest detection check for Solaris derived guests [GH-10081]
  - guest/windows: Be more explicit when invoking cmd.exe with mount_volume script [GH-9976]
  - host/linux: Fix sudo usage in NFS capability when modifying exports file [GH-10084]
  - host/windows: Remove localization dependency from SMB list generation [GH-10043]
  - provider/docker: Convert windows paths for volume mounts on docker driver [GH-10100]
  - provider/hyperv: Fix checkpoint configuration and properly disable automatic checkpoints by default [GH-9999]
  - provider/hyperv: Remove localization dependency from access check [GH-10000]
  - provider/hyperv: Enable ExposeVirtualizationExtensions only when available [GH-10079]
  - provider/virtualbox: Skip link-local when fixing IPv6 route [GH-9639, GH-10077]
  - push/ftp: Custom error when attempting to push too many files [GH-9952]
  - util/downloader: Prevent errors when Location header contains relative path [GH-10017]
  - util/guest_inspection: Prevent nmcli check from hanging when pty is enabled [GH-9926]
  - util/platform: Always force string type conversion on path [GH-9998]
- removed patch 0007-Support-system-installed-plugins.patch that has been included upstream
- removed patch 0027-now-use-rubygem-net-ssh-5.0.x.patch that is no longer necessary
* Fri Nov  9 2018 Johannes Kastl <kastl@b1-systems.de>
- link directories from /usr/share/vagrant/ to /usr/lib64/ruby/gems/2.5.0/gems/x.y.z/, to avoid ruby errors due to patch 0007
* Fri Nov  9 2018 Johannes Kastl <kastl@b1-systems.de>
- add Requires and BuildRequires for bash-completion to the vagrant-bash-completion subpackage
- move bash-completion file to %%{_datadir}/bash-completion/completions/ to avoid warnings
* Fri Nov  9 2018 Johannes Kastl <kastl@b1-systems.de>
- use patch 0007-Support-system-installed-plugins.patch on tumbleweed only, as this seems to break Leap 15.0 systems
* Wed Jul 11 2018 opensuse_buildservice@ojkastl.de
- added directory /usr/share/vagrant-plugins/plugins.d to spec file
* Mon Jul  9 2018 opensuse_buildservice@ojkastl.de
- added patch 0007-Support-system-installed-plugins.patch, removed patch 0008-Read-data-from-usr-share-vagrant.patch
  patch has been ported from Debians package for 2.0.2
  https://packages.debian.org/sid/vagrant
* Sun Jul  8 2018 opensuse_buildservice@ojkastl.de
- added Reqires for exact vagrant version to subpackages vagrant-vim, vagrant-emacs and vagrant-bash-completion
* Sun Jul  8 2018 opensuse_buildservice@ojkastl.de
- removed patch 0026-remove-dependency-on-win32-file.patch
* Sun Jul  8 2018 opensuse_buildservice@ojkastl.de
- update to 2.1.2
  IMPROVEMENTS
  - commands/suspend: Introduce flag for suspending all machines [GH-9829]
  - commands/global-status: Improve message about removing stale entries [GH-9856]
  - provider/hyperv: Attempt to determine import failure cause [GH-9936]
  - provider/hyperv: Update implementation. Include support for modifications on reload [GH-9872]
  - provider/hyperv: Validate maxmemory configuration setting [GH-9932]
  - provider/hyperv: Enable provider within WSL [GH-9943]
  - provider/hyperv: Add Hyper-V accessibility check on data directory path [GH-9944]
  - provisioners/ansible_local: Improve installation from PPA on Ubuntu guests. The compatibility is maintained only for active long-term support (LTS) versions, i.e. Ubuntu 12.04 (Precise Pangolin) is no longer supported. [GH-9879]
  BUG FIXES:
  - communicator/ssh: Update ssh private key file permission handling on Windows [GH-9923, GH-9900]
  - core: Display plugin commands in help [GH-9808]
  - core: Ensure guestpath or name is set with synced_folder option and dont set guestpath if not provided [GH-9692]
  - guest/debian: Fix netplan generation when using DHCP [GH-9855]
  - guest/debain: Update priority of network configuration file when using networkd [GH-9867]
  - guest/ubuntu: Update netplan config generation to detect NetworkManager [GH-9824]
  - guest/ubuntu: Fix failing Ansible installation from PPA on Bionic Beaver (18.04 LTS) [GH-9796]
  - host/windows: Prevent processing of last SMB line when using net share [GH-9917]
  - provisioner/chef: Prevent node_name set on configuration with chef_apply [GH-9916]
  - provisioner/salt: Remove usage of masterless? config attribute [GH-9833]
* Sun Jul  1 2018 opensuse_buildservice@ojkastl.de
- added patch 0027-now-use-rubygem-net-ssh-5.0.x.patch to allow builds with latest version of net-ssh in Tumbleweed
* Mon Jun  4 2018 opensuse_buildservice@ojkastl.de
- replace shebang in /usr/lib64/ruby/gems/*/gems/vagrant-2.1.1/.runner.sh
- remove shebang in /etc/bash_completion.d/vagrant.sh
* Mon Jun  4 2018 opensuse_buildservice@ojkastl.de
- added patch 0026-remove-dependency-on-win32-file.patch
* Mon Jun  4 2018 opensuse_buildservice@ojkastl.de
- update to 2.1.1
  IMPROVEMENTS:
  - guest/linux: Support builtin vboxsf module for shared folders [GH-9800]
  - host/windows: Update SMB capability to work without Get-SmbShare cmdlet [GH-9785]
  BUG FIXES:
  - core/triggers: Initialize internal trigger object for machine before initializing provider [GH-9784]
  - core/triggers: Ensure internal trigger fire does not get called if plugin installed [GH-9799]
  - provider/hyperv: Call import script with switchid instead of switchname [GH-9781]
* Mon Jun  4 2018 opensuse_buildservice@ojkastl.de
- update to 2.1.0
  FEATURES:
  - core: Integrate vagrant-triggers plugin functionality into core Vagrant [GH-9713]
  IMPROVEMENTS:
  - core: Improve messaging around not finding requested provider [GH-9735]
  - core: Disable exception reports by default [GH-9738]
  - core: Continue on if vagrant fails to parse metadata box for update [GH-9760]
  - hosts/linux: Support RDP capability within WSL [GH-9758]
  - hosts/windows: Add SMB default mount options capability and set default version to 2.0 [GH-9734]
  - provider/hyperv: Include neighbor check for MAC on guest IP detection [GH-9737]
  - provider/virtualbox: Do not require VirtualBox availability within WSL [GH-9759]
  - provisioner/chef_zero: Support arrays for data_bags_path [GH-9669]
  - util/downloader: Don't raise error if response is HTTP 416 [GH-9729]
  - util/platform: Update Hyper-V enabled check [GH-9746]
  BUG FIXES:
  - communicators/ssh: Log error and proceed on Windows private key permissions [GH-9769]
  - middleware/authentication: Prevent URL modification when no changes are required [GH-9730]
  - middleware/authentication: Ignore URLs which cannot be parsed [GH-9739]
  - provider/hyperv: Reference switches by ID instead of name [GH-9747]
  - provider/docker: Use Util::SafeExec if docker-exec is run with -t option [GH-9761]
  - provisioner/chef: Trim drive letter from path on Windows [GH-9766]
  - provisioner/puppet: Properly finalize structured_facts config option [GH-9720]
  - util/platform: Fix original WSL to Windows path for "root" directory [GH-9696]
* Mon Jun  4 2018 opensuse_buildservice@ojkastl.de
- update to 2.0.4
  FEATURES:
  - core: Vagrant aliases [GH-9504]
  IMPROVEMENTS:
  - communicators/ssh: Update file permissions when generating new key pairs [GH-9676]
  - core: Make resolv-replace usage opt-in instead of opt-out [GH-9644]
  - core: Suppress error messages from checkpoint runs [GH-9645]
  - guests/coreos: Identify operating systems closely related to CoreOS [GH-9600]
  - guests/debian: Adjust network configuration file prefix to 50- [GH-9646]
  - guests/photon: Less specific string grep to fix PhotonOS 2.0 detection [GH-9528]
  - guests/windows: Fix slow timeout when updating windows hostname [GH-9578]
  - hosts/windows: Make powershell version detection timeout configurable [GH-9506]
  - providers/virtualbox: Improve network collision error message [GH-9685]
  - provisioner/chef_solo: Improve Windows drive letter removal hack for remote paths[GH-9490]
  - provisioner/chef_zero: File path expand all chef_zero config path options [GH-9690]
  - provisioner/puppet: Puppet structured facts toyaml on provisioner [GH-9670]
  - provisioner/salt: Add master_json_config & minion_json_config options [GH-9420]
  - util/platform: Warn on ArgumentError exceptions from encoding [GH-9506]
  BUG FIXES:
  - commands/package: Fix uninitialized constant error [GH-9654]
  - communicators/winrm: Fix command filter to properly parse commands [GH-9673]
  - hosts/windows: Properly respect the VAGRANT_PREFER_SYSTEM_BIN environment variable [GH-9503]
  - hosts/windows: Fix virtualbox shared folders path for windows guests [GH-8099]
  - guests/freebsd: Fix typo in command that manages configuring networks [GH-9705]
  - util/checkpoint_client: Respect VAGRANT_CHECKPOINT_DISABLE environment variable [GH-9659]
  - util/platform: Use --version instead of version for WSL validation [GH-9674]
- rebased patch 0024-do-not-depend-on-wdm.patch
* Mon Jun  4 2018 opensuse_buildservice@ojkastl.de
- update to version 2.0.3
  - > removed patch 0006-Relax-dependency-resolution.patch
  IMPROVEMENTS:
  - guests/solaris: More explicit Solaris 11 and inherit SmartOS from Solaris [GH-9398]
  - hosts/windows: Add support for latest WSL release [GH-9525, GH-9300]
  - plugins/login: Update middleware to re-map hosts and warn on custom server [GH-9499]
  - providers/hyper-v: Exit if Hyper-V is enabled and VirtualBox provider is used [GH-9456]
  - provisioners/salt: Change to a temporary directory before downloading script files [GH-9351]
  - sycned_folders/nfs: Default udp to false when using version 4 [GH-8828]
  - util/downloader: Notify on host redirect [GH-9344]
  BUG FIXES:
  - core: Use provider override when specifying box_version [GH-9502]
  - guests/debian: Renew DHCP lease on hostname change [GH-9405]
  - guests/debian: Point hostname to 127.0.1.1 in /etc/hosts [GH-9404]
  - guests/debian: Update systemd? check for guest inspection [GH-9459]
  - guests/debian: Use ip route in dhcp template [GH-8730]
  - guests/gentoo: Disable if/netplugd when setting up a static ip on a gentoo guest using openrc [GH-9261]
  - guests/openbsd: Atomically apply new hostname.if(5) [GH-9265]
  - hosts/windows: Fix halt problem when determining powershell version on old powershells [GH-9470]
  - hosts/windows: Convert to windows path if on WSL during vbox export [GH-9518]
  - providers/virtualbox: Fix hostonly matching not respecting :name argument [GH-9302]
  - util/credential_scrubber: Ignore empty strings [GH-9472, GH-9462]
* Mon Jun  4 2018 opensuse_buildservice@ojkastl.de
- do no longer use /usr/share/vim/current for vagrant-vim, rather use the approach used by
  package openSUSE:Leap:15.0/vim-plugins: %%{_datadir}/vim/site/plugin/
* Sun May 13 2018 opensuse_buildservice@ojkastl.de
- re-added vim_data_dir macro until there is a better way to do this
* Wed May  9 2018 opensuse_buildservice@ojkastl.de
- removed definition for vim_data_dir from spec file, to get rid of conflicts with vim80 package
* Wed May  2 2018 jengelh@inai.de
- Use noun phrase in summary.
- Substitute obsolete %%__-type macro indirections.
* Thu Mar  1 2018 opensuse_buildservice@ojkastl.de
- removed some files during %%install to avoid warnings on SLES12/Leap42.x
* Wed Feb 28 2018 opensuse_buildservice@ojkastl.de
- update to version 2.0.2
  - > removed patch 0001-Disable-Checkpoint.patch that has been upstreamed
  - > removed patch 0031-allow-builds-with-ruby2.5.patch
  FEATURES:
  - core: Provide mechanism for removing sensitive data from output [GH-9276]
  - core: Relax Ruby constraints to include 2.5 [GH-9363]
  - core: Hide sensitive values in output [GH-9369]
  - command/init: Support custom Vagrantfile templates [GH-9202]
  - guests: Add support for the Haiku operating system [GH-7805, GH-9245]
  - synced_folders/smb: Add support for macOS hosts [GH-9294]
  - vagrant-spec: Update vagrant-spec to include Windows platforms and updated linux boxes [GH-9183]
  IMPROVEMENTS:
  - config/ssh: Deprecate :paranoid in favor of :verify_host_key [GH-9341]
  - core: Add optional timestamp prefix on log output [GH-9269]
  - core: Print more helpful error message for NameEror exceptions in Vagrantfiles [GH-9252]
  - core: Update checkpoint implementation to announce updates and support notifications [GH-9380]
  - core: Use Ruby's Resolv by default [GH-9394]
  - docs: Include virtualbox 5.2.x as supported in docs [GH-9237]
  - docs: Improve how to pipe debug log on powershell [GH-9330]
  - guests/amazon: Improve guest detection [GH-9307]
  - guests/debian: Update guest configure networks [GH-9338]
  - guests/dragonflybsd: Base guest on FreeBSD to inherit more functionality [GH-9205]
  - guests/linux: Improve NFS service name detection and interactions [GH-9274]
  - guests/linux: Support mount option overrides for SMB mounts [GH-9366]
  - guests/linux: Use `ip` for reading guest address if available [GH-9315]
  - guests/solaris: Improve guest detection for alternatives [GH-9295]
  - hosts/windows: Check credentials during SMB prepare [GH-9365]
  - providers/hyper-v: Ensure Hyper-V cmdlets are fully qualified [GH-8863]
  - middleware/authentication: Add app.vagrantup.com to allowed hosts [GH-9145]
  - provisioners/shell: Support hiding environment variable values in output [GH-9367]
  - providers/virtualbox: Add a clean error message for invalid IP addresses [GH-9275]
  - providers/virtualbox: Introduce flag for SharedFoldersEnableSymlinksCreate setting [GH-9354]
  - providers/virtualbox: Provide warning for SharedFoldersEnableSymlinksCreate setting [GH-9389]
  - provisioners/salt: Fixes timeout issue in salt bootstrapping for windows [GH-8992]
  - synced_folders/smb: Update Windows implementation [GH-9294]
  - util/ssh: Attempt to locate local ssh client before attempting installer provided [GH-9400]
  BUG FIXES:
  - commands/box: Show all box providers with `update outdated --global` [GH-9347]
  - commands/destroy: Exit 0 if vagrant destroy finds no running vms [GH-9251]
  - commands/package: Fix --output path with specified folder [GH-9131]
  - guests/suse: Do not use full name when setting hostname [GH-9212]
  - providers/hyper-v: Fix enable virtualization extensions on import [GH-9255]
  - provisioners/ansible(both): Fix broken 'ask_sudo_pass' option [GH-9173]
* Wed Feb 28 2018 opensuse_buildservice@ojkastl.de
- added patch 0031-allow-builds-with-ruby2.5.patch to allow building with ruby2.5
* Wed Feb 28 2018 opensuse_buildservice@ojkastl.de
- update to version 2.0.1
  FEATURES:
    core: Introduce Ruby 2.4 to Vagrant [GH-9102]
    providers/virtualbox: Virtualbox 5.2 support [GH-8955]
  IMPROVEMENTS:
    command/destroy: Introduce parallel destroy for certain providers [GH-9127]
    communicators/winrm: Include APIPA check within ready check [GH-8997]
    core: Clear POSIXLY_CORRECT when using optparse [GH-8685]
    docs: Add auto_start_action and auto_stop_action to docs. [GH-9029]
    docs: Fix typo in box format doc [GH-9100]
    provisioners/chef: Handle chef provisioner reboot request [GH-8874]
    providers/salt: Support Windows Salt Minions greater than 2016.x.x [GH-8926]
    provisioners/salt: Add wget to bootstrap_salt options when fetching installer file [GH-9112]
    provisioners/shell: Use ui.detail for displaying output [GH-8983]
    util/downloader: Use CURL_CA_BUNDLE environment variable [GH-9135]
  BUG FIXES:
    communicators/ssh: Retry on Errno::EPIPE exceptions [GH-9065]
    core: Rescue more exceptions when checking if port is open [GH-8517]
    guests/solaris11: Inherit from Solaris guest and keep solaris11 specific methods [GH-9034]
    guests/windows: Split out cygwin path helper for msys2/cygwin paths and ensure cygpath exists [GH-8972]
    guests/windows: Specify expected shell when executing on guest (fixes winssh communicator usage) [GH-9012]
    guests/windows: Include WinSSH Communicator when using insert_public_key [GH-9105]
    hosts/windows: Check for vagrant.exe when validating versions within WSL [GH-9107, GH-8962]
    providers/docker: Isolate windows check within executor to handle running through VM [GH-8921]
    providers/hyper-v: Properly invoke Auto stop action [GH-9000]
    provisioners/puppet: Fix winssh communicator support in puppet provisioner [GH-9014]
    virtualbox/synced_folders: Allow synced folders to contain spaces in the guest path [GH-8995]
- removed patches, that have been merged upstream
  - 0010-virtualbox-5.2-support.patch
  - 0020-also-build-with-ruby2.4.patch
  - 0021-Use-Integer-instead-of-Fixnum-for-Ruby-2.4-compatibi.patch
  - 0022-Do-not-use-deprecated-API.patch
* Wed Feb 28 2018 opensuse_buildservice@ojkastl.de
- update to version 2.0.0
  IMPROVEMENTS:
    commands/login: Add support for two-factor authentication [GH-8935]
    commands/ssh-config: Properly display windows path if invoked from msys2 or cygwin [GH-8915]
    guests/alt: Add support for ALT Linux [GH-8746]
    guests/kali: Fix file permissions on guest plugin ruby files [GH-8950]
    hosts/linux: Provide common systemd detection for services interaction, fix NFS host interactions [GH-8938]
    providers/salt: Remove duplicate stdout, stderr output from salt [GH-8767]
    providers/salt: Introduce salt_call_args and salt_args option for salt provisioner [GH-8927]
    providers/virtualbox: Improving resilience of some VirtualBox commands [GH-8951]
    provisioners/ansible(both): Add the compatibility_mode option, with auto-detection enabled by default [GH-8913, GH-6570]
    provisioners/ansible: Add the version option to the host-based provisioner [GH-8913, GH-8914]
    provisioners/ansible(both): Add the become and become_user options with deprecation of sudo and sudo_user options [GH-8913, GH-6570]
    provisioners/ansible: Add the ask_become_pass option with deprecation of the ask_sudo_pass option [GH-8913, GH-6570]
  BUG FIXES:
    guests/shell_expand_guest_path : Properly expand guest paths that include relative path alias [GH-8918]
    hosts/linux: Remove duplicate export folders before writing /etc/exports [GH-8945]
    provisioners/ansible(both): Add single quotes to the inventory host variables, only when necessary [GH-8597]
    provisioners/ansible(both): Add the "all:vars" section to the inventory when defined in groups option [GH-7730]
    provisioners/ansible_local: Extra variables are no longer truncated when a dollar ($) character is present [GH-7735]
    provisioners/file: Align file provisioner functionality on all platforms [GH-8939]
    util/ssh: Properly quote key path for IdentityFile option to allow for spaces [GH-8924]
  BREAKING CHANGES:
    Both Ansible provisioners are now capable of automatically setting the compatibility_mode that best fits with the Ansible version in use. You may encounter some compatibility issues when upgrading. If you were using Ansible 2.x and referring to the _ssh-prefixed variables present in the generated inventory (e.g. ansible_ssh_host). In this case, you can fix your Vagrant setup by setting compatibility_mode = "1.8", or by migrating to the new variable names (e.g. ansible_host).
* Wed Feb 28 2018 opensuse_buildservice@ojkastl.de
- update to version 1.9.8 (August 23, 2017)
  IMPROVEMENTS:
    bash: Add box prune to contrib bash completion [GH-8806]
    commands/login: Ask for description of Vagrant Cloud token [GH-8876]
    commands/validate: Improve functionality of the validate command [GH-8889]n
    core: Updated Vagrants rspec gem to 3.5.0 [GH-8850]
    core: Validate powershell availability and version before use [GH-8839]
    core: Introduce extra_args setting for ssh configs [GH-8895]
    docs: Align contrib/sudoers file for ubuntu linux with docs [GH-8842]
    provider/hyperv: Prefer IPv4 guest address [GH-8831, GH-8759]
    provisioners/chef: Add config option omnibus_url for chef provisioners [GH-8682]
    provisioners/chef: Improve exception handling around missing folder paths [GH-8775]
  BUG FIXES:
    box/update: Add force flag for box upgrade command [GH-8871]
    commands/rsync-auto: Ensure relative dirs are still rsync'd if defined [GH-8781]
    commands/up: Disable install providers when using global id on vagrant up [GH-8910]
    communicators/winssh: Fix public key insertion to retain ACL [GH-8790]
    core: Update util/ssh to use -o for identity files [GH-8786]
    guests/freebsd: Fix regex for listing network devices on some FreeBSD boxes. [GH-8760]
    hosts/windows: Prevent control characters in version check for WSL [GH-8902, GH-8901]
    providers/docker: Split String type links into Array when using compose [GH-8837, GH-8821]
    providers/docker: Expand relative volume paths correctly [GH-8838, GH-8822]
    providers/docker: Error when compose option enabled with force_host_vm [GH-8911]
    provisioners/ansible: Update to use -o for identity files [GH-8786]
    provisioners/file: Ensure remote folder exists prior to scp file or folder [GH-8880]
    provisioners/salt: Fix error case when github is unreachable for installer [GH-8864]
    provisioners/shell: Allow frozen string scripts [GH-8875]
    provisioners/puppet: Remove --manifestdir flag from puppet apply in provisioner [GH-8797]
    synced_folders/rsync: Correctly format IPv6 host [GH-8840, GH-8809]
* Wed Feb 28 2018 opensuse_buildservice@ojkastl.de
- tried to nail down the BuildReqire dependencies where possible,
  to avoid build failures due to mismatches between BuildRequires
  and vagrant's own dependencies in vagrant.gemspec
* Tue Jan 30 2018 robert.munteanu@gmail.com
- No longer hardcode the ruby version, it was enough to lock down
  the rubygem versions
* Sat Jan 27 2018 robert.munteanu@gmail.com
- Explicitly build against ruby 2.5 for now
* Thu Oct 26 2017 tmkn@tmkn.uk
- Add 0025-do-not-abuse-relative-paths-in-docker-plugin.patch to
  make docker plugin work.
* Sun Oct 22 2017 robert.munteanu@gmail.com
- Added upstream patch 0010-virtualbox-5.2-support.patch to allow
  running with upcoming Virtualbox 5.2
* Thu Sep 28 2017 dimstar@opensuse.org
- Lock rubygem-net-ssh to 4.1 branch, matching the resulting
  dependency from vagrant.gemspec:
  + add_dependency "net-ssh", "~> 4.1.0", meaning anything from
    4.1.0 to just before 4.2 is acceptable.
* Tue Aug 29 2017 robert.munteanu@gmail.com
- Added 0024-do-not-depend-on-wdm.patch - that rubygem only works
  on windows
* Wed Aug 16 2017 robert.munteanu@gmail.com
- Rebase 0023-vbox-fix-package.patch for Vagrant 1.9.7
- Fix various 'have choice for ...' errors
* Sun Aug 13 2017 robert.munteanu@gmail.com
- add 0023-vbox-fix-package.patch ( boo#1044087 )
* Tue Jul 25 2017 opensuse_buildservice@ojkastl.de
- renamed patch 0010-also-build-with-ruby2.4.patch to
  0020-also-build-with-ruby2.4.patch
- add patches for ruby2.4 compatibility
  * added patch
    0021-Use-Integer-instead-of-Fixnum-for-Ruby-2.4-compatibi.patch
  * added patch 0022-Do-not-use-deprecated-API.patch
* Mon Jul 24 2017 opensuse_buildservice@ojkastl.de
- update to version 1.9.7
- removed patch 0005-Support-system-installed-plugins.patch that
  no longer applies
- added patch 0010-also-build-with-ruby2.4.patch that allows builds
  with ruby2.4, even if vagrant states otherwise
  (https://github.com/mitchellh/vagrant/blob/master/vagrant.gemspec#L15)
* Thu Jun 15 2017 opensuse_buildservice@ojkastl.de
- as rubygem-childprocess has been updated to 0.7 in d:l:r:e, which
  does not work with vagrant, a BuildRequires for
  rubygem-childprocess <= 0.7 has been added
* Sun May 21 2017 opensuse_buildservice@ojkastl.de
- update to version 1.9.5
- removed patch 0007-Update-command.rb.patch, that has been
  integrated upstream
- rebased patches to allow patching version 1.9.5 instead of 1.9.1
- added explicit BuildRequires for rubygems needed to get vagrant
  to build
* Tue Mar  7 2017 robert.munteanu@gmail.com
- Fix build in factory - failed due to
  "have choice for rubygem(ruby:2.2.0:nokogiri)"
* Mon Mar  6 2017 jloehel@suse.com
- Add 0009-plugins-don-t-abuse-require_relative.patch
  to fix 'vagrant fails configuring VM network' (bsc#1026449)
* Thu Feb 16 2017 robert.munteanu@gmail.com
- Fix build on openSUSE Leap 42.2
* Thu Feb 16 2017 robert.munteanu@gmail.com
- Prevent 'have choice for rubygem(ruby:2.1.0:mime-types) >= 1.16'
  for Leap 42.{1,2}
* Mon Feb 13 2017 robert.munteanu@gmail.com
- Re-add 0008-Read-data-from-usr-share-vagrant.patch as vagrant
  fails at runtime otherwise. Debian dropped it due to installing
  the package using rubygems layout, but we don't do that
* Mon Feb 13 2017 robert.munteanu@gmail.com
- sync with 1.9.1
  https://packages.debian.org/sid/main/vagrant
- Patch changelog
  + Added
  * 0001-Disable-Checkpoint.patch
  * 0002-bin-vagrant-silence-warning-about-installer.patch
  * 0003-Use-a-private-temporary-dir.patch
  * 0004-linux-cap-halt-don-t-wait-for-shutdown-h-now-to-fini.patch
  * 0005-Support-system-installed-plugins.patch
  * 0006-Relax-dependency-resolution.patch
  * 0007-Update-command.rb.patch
  + Deleted
  * 0002-Disable-Checkpoint.patch
  * 0003-VERSION-fallback-to-usr-share-vagrant-version.txt.patch
  * 0004-bin-vagrant-silence-warning-about-installer.patch
  * 0005-Read-data-from-usr-share-vagrant.patch
  * 0006-Look-up-vagrant-pre-rubygems.rb-from-the-installed-p.patch
  * 0007-Make-Bundler-also-lookup-into-rubygems-integration-p.patch
  * 0008-Use-a-private-temporary-dir.patch
  * 0009-linux-cap-halt-don-t-wait-for-shutdown-h-now-to-fini.patch
  * 0011-Relax-dependency-resolution.patch
  * 0011-Support-system-installed-plugins.patch
  * 0012-require-vagrant-version-from-system.patch
* Tue Sep  6 2016 mmanno@suse.com
- sync with 1.8.5
  https://packages.debian.org/sid/main/vagrant
* Fri Mar  4 2016 dmacvicar@suse.de
- sync with 1.8.1
  https://packages.debian.org/sid/main/vagrant
- remove
  0001-SUSE-flavored-systems-uses-STARTMODE-and-not-ONBOOT.patch
  (already upstream in 1.8.1)
* Mon Nov 23 2015 dmacvicar@suse.de
- add Provides/Obsoletes
- install manpage
* Sun Nov  8 2015 dmacvicar@suse.de
- add 0001-SUSE-flavored-systems-uses-STARTMODE-and-not-ONBOOT.patch
  to fix reboot with dhcp
* Sun Nov  8 2015 dmacvicar@suse.de
- split out vim, emacs and bash files
* Sun Nov  8 2015 dmacvicar@suse.de
- follow plugin convention from Debian package by Antonio Terceiro
  and Laurent Bigonville
- use patches from https://packages.debian.org/sid/main/vagrant
* Tue Sep  1 2015 mrueckert@suse.de
- sync BR with gemspec
- make sure we notice when the gemspec isnt working anymore
  by running bundle exec bin/vagrant --version
* Tue Sep  1 2015 mrueckert@suse.de
- 1.7.4
